"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.gears._420 import AccuracyGrades
    from mastapy._private.gears._421 import AGMAToleranceStandard
    from mastapy._private.gears._422 import BevelHypoidGearDesignSettings
    from mastapy._private.gears._423 import BevelHypoidGearRatingSettings
    from mastapy._private.gears._424 import CentreDistanceChangeMethod
    from mastapy._private.gears._425 import CoefficientOfFrictionCalculationMethod
    from mastapy._private.gears._426 import ConicalGearToothSurface
    from mastapy._private.gears._427 import ContactRatioDataSource
    from mastapy._private.gears._428 import ContactRatioRequirements
    from mastapy._private.gears._429 import CylindricalFlanks
    from mastapy._private.gears._430 import CylindricalMisalignmentDataSource
    from mastapy._private.gears._431 import DeflectionFromBendingOption
    from mastapy._private.gears._432 import DINToleranceStandard
    from mastapy._private.gears._433 import GearFlanks
    from mastapy._private.gears._434 import GearNURBSSurface
    from mastapy._private.gears._435 import GearSetDesignGroup
    from mastapy._private.gears._436 import GearSetModes
    from mastapy._private.gears._437 import GearSetOptimisationResult
    from mastapy._private.gears._438 import GearSetOptimisationResults
    from mastapy._private.gears._439 import GearSetOptimiser
    from mastapy._private.gears._440 import GearWindageAndChurningLossCalculationMethod
    from mastapy._private.gears._441 import Hand
    from mastapy._private.gears._442 import ISOToleranceStandard
    from mastapy._private.gears._443 import LubricationMethodForNoLoadLossesCalc
    from mastapy._private.gears._444 import LubricationMethods
    from mastapy._private.gears._445 import MicroGeometryInputTypes
    from mastapy._private.gears._446 import MicroGeometryModel
    from mastapy._private.gears._447 import (
        MicropittingCoefficientOfFrictionCalculationMethod,
    )
    from mastapy._private.gears._448 import NamedPlanetAngle
    from mastapy._private.gears._449 import GearMeshOilInjectionDirection
    from mastapy._private.gears._450 import OilJetFlowRateSpecificationMethod
    from mastapy._private.gears._451 import OilJetVelocitySpecificationMethod
    from mastapy._private.gears._452 import PlanetaryDetail
    from mastapy._private.gears._453 import PlanetaryRatingLoadSharingOption
    from mastapy._private.gears._454 import PocketingPowerLossCoefficients
    from mastapy._private.gears._455 import PocketingPowerLossCoefficientsDatabase
    from mastapy._private.gears._456 import QualityGradeTypes
    from mastapy._private.gears._457 import SafetyRequirementsAGMA
    from mastapy._private.gears._458 import (
        SpecificationForTheEffectOfOilKinematicViscosity,
    )
    from mastapy._private.gears._459 import SpiralBevelRootLineTilt
    from mastapy._private.gears._460 import SpiralBevelToothTaper
    from mastapy._private.gears._461 import TESpecificationType
    from mastapy._private.gears._462 import WormAddendumFactor
    from mastapy._private.gears._463 import WormType
    from mastapy._private.gears._464 import ZerolBevelGleasonToothTaperOption
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears._420": ["AccuracyGrades"],
        "_private.gears._421": ["AGMAToleranceStandard"],
        "_private.gears._422": ["BevelHypoidGearDesignSettings"],
        "_private.gears._423": ["BevelHypoidGearRatingSettings"],
        "_private.gears._424": ["CentreDistanceChangeMethod"],
        "_private.gears._425": ["CoefficientOfFrictionCalculationMethod"],
        "_private.gears._426": ["ConicalGearToothSurface"],
        "_private.gears._427": ["ContactRatioDataSource"],
        "_private.gears._428": ["ContactRatioRequirements"],
        "_private.gears._429": ["CylindricalFlanks"],
        "_private.gears._430": ["CylindricalMisalignmentDataSource"],
        "_private.gears._431": ["DeflectionFromBendingOption"],
        "_private.gears._432": ["DINToleranceStandard"],
        "_private.gears._433": ["GearFlanks"],
        "_private.gears._434": ["GearNURBSSurface"],
        "_private.gears._435": ["GearSetDesignGroup"],
        "_private.gears._436": ["GearSetModes"],
        "_private.gears._437": ["GearSetOptimisationResult"],
        "_private.gears._438": ["GearSetOptimisationResults"],
        "_private.gears._439": ["GearSetOptimiser"],
        "_private.gears._440": ["GearWindageAndChurningLossCalculationMethod"],
        "_private.gears._441": ["Hand"],
        "_private.gears._442": ["ISOToleranceStandard"],
        "_private.gears._443": ["LubricationMethodForNoLoadLossesCalc"],
        "_private.gears._444": ["LubricationMethods"],
        "_private.gears._445": ["MicroGeometryInputTypes"],
        "_private.gears._446": ["MicroGeometryModel"],
        "_private.gears._447": ["MicropittingCoefficientOfFrictionCalculationMethod"],
        "_private.gears._448": ["NamedPlanetAngle"],
        "_private.gears._449": ["GearMeshOilInjectionDirection"],
        "_private.gears._450": ["OilJetFlowRateSpecificationMethod"],
        "_private.gears._451": ["OilJetVelocitySpecificationMethod"],
        "_private.gears._452": ["PlanetaryDetail"],
        "_private.gears._453": ["PlanetaryRatingLoadSharingOption"],
        "_private.gears._454": ["PocketingPowerLossCoefficients"],
        "_private.gears._455": ["PocketingPowerLossCoefficientsDatabase"],
        "_private.gears._456": ["QualityGradeTypes"],
        "_private.gears._457": ["SafetyRequirementsAGMA"],
        "_private.gears._458": ["SpecificationForTheEffectOfOilKinematicViscosity"],
        "_private.gears._459": ["SpiralBevelRootLineTilt"],
        "_private.gears._460": ["SpiralBevelToothTaper"],
        "_private.gears._461": ["TESpecificationType"],
        "_private.gears._462": ["WormAddendumFactor"],
        "_private.gears._463": ["WormType"],
        "_private.gears._464": ["ZerolBevelGleasonToothTaperOption"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AccuracyGrades",
    "AGMAToleranceStandard",
    "BevelHypoidGearDesignSettings",
    "BevelHypoidGearRatingSettings",
    "CentreDistanceChangeMethod",
    "CoefficientOfFrictionCalculationMethod",
    "ConicalGearToothSurface",
    "ContactRatioDataSource",
    "ContactRatioRequirements",
    "CylindricalFlanks",
    "CylindricalMisalignmentDataSource",
    "DeflectionFromBendingOption",
    "DINToleranceStandard",
    "GearFlanks",
    "GearNURBSSurface",
    "GearSetDesignGroup",
    "GearSetModes",
    "GearSetOptimisationResult",
    "GearSetOptimisationResults",
    "GearSetOptimiser",
    "GearWindageAndChurningLossCalculationMethod",
    "Hand",
    "ISOToleranceStandard",
    "LubricationMethodForNoLoadLossesCalc",
    "LubricationMethods",
    "MicroGeometryInputTypes",
    "MicroGeometryModel",
    "MicropittingCoefficientOfFrictionCalculationMethod",
    "NamedPlanetAngle",
    "GearMeshOilInjectionDirection",
    "OilJetFlowRateSpecificationMethod",
    "OilJetVelocitySpecificationMethod",
    "PlanetaryDetail",
    "PlanetaryRatingLoadSharingOption",
    "PocketingPowerLossCoefficients",
    "PocketingPowerLossCoefficientsDatabase",
    "QualityGradeTypes",
    "SafetyRequirementsAGMA",
    "SpecificationForTheEffectOfOilKinematicViscosity",
    "SpiralBevelRootLineTilt",
    "SpiralBevelToothTaper",
    "TESpecificationType",
    "WormAddendumFactor",
    "WormType",
    "ZerolBevelGleasonToothTaperOption",
)



"""AGMA2000A88AccuracyGrader"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances import (
    _1278,
)

_AGMA2000A88_ACCURACY_GRADER = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical.AccuracyAndTolerances",
    "AGMA2000A88AccuracyGrader",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances import (
        _1277,
        _1279,
        _1290,
    )

    Self = TypeVar("Self", bound="AGMA2000A88AccuracyGrader")
    CastSelf = TypeVar(
        "CastSelf", bound="AGMA2000A88AccuracyGrader._Cast_AGMA2000A88AccuracyGrader"
    )


__docformat__ = "restructuredtext en"
__all__ = ("AGMA2000A88AccuracyGrader",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AGMA2000A88AccuracyGrader:
    """Special nested class for casting AGMA2000A88AccuracyGrader to subclasses."""

    __parent__: "AGMA2000A88AccuracyGrader"

    @property
    def cylindrical_accuracy_grader(
        self: "CastSelf",
    ) -> "_1278.CylindricalAccuracyGrader":
        return self.__parent__._cast(_1278.CylindricalAccuracyGrader)

    @property
    def cylindrical_accuracy_grader_base(
        self: "CastSelf",
    ) -> "_1279.CylindricalAccuracyGraderBase":
        from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances import (
            _1279,
        )

        return self.__parent__._cast(_1279.CylindricalAccuracyGraderBase)

    @property
    def customer_102agma2000_accuracy_grader(
        self: "CastSelf",
    ) -> "_1277.Customer102AGMA2000AccuracyGrader":
        from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances import (
            _1277,
        )

        return self.__parent__._cast(_1277.Customer102AGMA2000AccuracyGrader)

    @property
    def agma2000a88_accuracy_grader(self: "CastSelf") -> "AGMA2000A88AccuracyGrader":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class AGMA2000A88AccuracyGrader(_1278.CylindricalAccuracyGrader):
    """AGMA2000A88AccuracyGrader

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _AGMA2000A88_ACCURACY_GRADER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def adjusted_number_of_teeth(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AdjustedNumberOfTeeth")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def allowable_pitch_variation(self: "Self") -> "_1290.OverridableTolerance":
        """mastapy.gears.gear_designs.cylindrical.accuracy_and_tolerances.OverridableTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AllowablePitchVariation")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def profile_tolerance(self: "Self") -> "_1290.OverridableTolerance":
        """mastapy.gears.gear_designs.cylindrical.accuracy_and_tolerances.OverridableTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ProfileTolerance")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def radial_runout_tolerance(self: "Self") -> "_1290.OverridableTolerance":
        """mastapy.gears.gear_designs.cylindrical.accuracy_and_tolerances.OverridableTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RadialRunoutTolerance")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def tooth_alignment_tolerance(self: "Self") -> "_1290.OverridableTolerance":
        """mastapy.gears.gear_designs.cylindrical.accuracy_and_tolerances.OverridableTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ToothAlignmentTolerance")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def toothto_tooth_composite_tolerance(self: "Self") -> "_1290.OverridableTolerance":
        """mastapy.gears.gear_designs.cylindrical.accuracy_and_tolerances.OverridableTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ToothtoToothCompositeTolerance")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def total_composite_tolerance(self: "Self") -> "_1290.OverridableTolerance":
        """mastapy.gears.gear_designs.cylindrical.accuracy_and_tolerances.OverridableTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TotalCompositeTolerance")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_AGMA2000A88AccuracyGrader":
        """Cast to another type.

        Returns:
            _Cast_AGMA2000A88AccuracyGrader
        """
        return _Cast_AGMA2000A88AccuracyGrader(self)



"""GearMeshEfficiencyRatingMethod"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_GEAR_MESH_EFFICIENCY_RATING_METHOD = python_net_import(
    "SMT.MastaAPI.Gears.Rating", "GearMeshEfficiencyRatingMethod"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="GearMeshEfficiencyRatingMethod")
    CastSelf = TypeVar(
        "CastSelf",
        bound="GearMeshEfficiencyRatingMethod._Cast_GearMeshEfficiencyRatingMethod",
    )


__docformat__ = "restructuredtext en"
__all__ = ("GearMeshEfficiencyRatingMethod",)


class GearMeshEfficiencyRatingMethod(Enum):
    """GearMeshEfficiencyRatingMethod

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _GEAR_MESH_EFFICIENCY_RATING_METHOD

    ISOTR_1417912001 = 0
    ISOTR_1417922001 = 1
    USERSPECIFIED_TOOTH_LOSS_FACTOR = 2
    VELEX_AND_VILLE = 3
    HENRIOT = 4
    BUCKINGHAM = 5
    LTCA_MEAN_SLIDING_POWER_LOSS = 6
    SCRIPT = 7


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


GearMeshEfficiencyRatingMethod.__setattr__ = __enum_setattr
GearMeshEfficiencyRatingMethod.__delattr__ = __enum_delattr



"""ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
    _6373,
)

_SHAFT_TO_MOUNTABLE_COMPONENT_CONNECTION_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION = (
    python_net_import(
        "SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalysesSingleExcitation",
        "ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation",
    )
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2942, _2944, _2946
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7936,
        _7939,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
        _6394,
        _6405,
        _6414,
        _6457,
    )
    from mastapy._private.system_model.connections_and_sockets import _2555

    Self = TypeVar(
        "Self",
        bound="ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation",
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation._Cast_ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation:
    """Special nested class for casting ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation to subclasses."""

    __parent__: "ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation"

    @property
    def abstract_shaft_to_mountable_component_connection_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6373.AbstractShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation":
        return self.__parent__._cast(
            _6373.AbstractShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation
        )

    @property
    def connection_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6405.ConnectionHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6405,
        )

        return self.__parent__._cast(_6405.ConnectionHarmonicAnalysisOfSingleExcitation)

    @property
    def connection_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7939.ConnectionStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7939,
        )

        return self.__parent__._cast(_7939.ConnectionStaticLoadAnalysisCase)

    @property
    def connection_analysis_case(self: "CastSelf") -> "_7936.ConnectionAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7936,
        )

        return self.__parent__._cast(_7936.ConnectionAnalysisCase)

    @property
    def connection_analysis(self: "CastSelf") -> "_2942.ConnectionAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2942

        return self.__parent__._cast(_2942.ConnectionAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def coaxial_connection_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6394.CoaxialConnectionHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6394,
        )

        return self.__parent__._cast(
            _6394.CoaxialConnectionHarmonicAnalysisOfSingleExcitation
        )

    @property
    def cycloidal_disc_central_bearing_connection_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> (
        "_6414.CycloidalDiscCentralBearingConnectionHarmonicAnalysisOfSingleExcitation"
    ):
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6414,
        )

        return self.__parent__._cast(
            _6414.CycloidalDiscCentralBearingConnectionHarmonicAnalysisOfSingleExcitation
        )

    @property
    def planetary_connection_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6457.PlanetaryConnectionHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6457,
        )

        return self.__parent__._cast(
            _6457.PlanetaryConnectionHarmonicAnalysisOfSingleExcitation
        )

    @property
    def shaft_to_mountable_component_connection_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation(
    _6373.AbstractShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation
):
    """ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = (
        _SHAFT_TO_MOUNTABLE_COMPONENT_CONNECTION_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION
    )

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def connection_design(self: "Self") -> "_2555.ShaftToMountableComponentConnection":
        """mastapy.system_model.connections_and_sockets.ShaftToMountableComponentConnection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation":
        """Cast to another type.

        Returns:
            _Cast_ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation
        """
        return (
            _Cast_ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation(
                self
            )
        )



"""Module to simplify loading example files."""

from __future__ import annotations

from abc import ABC, ABCMeta
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from typing import Any, TypeVar

    from mastapy.system_model import Design

    Self_ExamplesMeta = TypeVar("Self_ExamplesMeta", "ExamplesMeta")
    Self_ExampleName = TypeVar("Self_ExampleName", "ExampleName")

from mastapy._private._internal.utility import StrEnum


class ExamplesMeta(ABCMeta):
    """Meta class that disables attribute modification."""

    def __setattr__(self: "Self_ExamplesMeta", name: str, value: "Any") -> None:
        """Override of the setattr magic method."""
        if name.startswith("_"):
            super(ExamplesMeta, self).__setattr__(name, value)
        else:
            raise Exception("You cannot modify any of the example paths.") from None


class ExampleName(StrEnum):
    """Enum to simplify loading examples.

    >>> Design.load_example(ExampleName.SIMPLE_HOUSING)
    """

    SIMPLE_PULL_BELT_CVT_MODEL = "Automotive: CVT: Simple Pull-Belt CVT model"
    """Automotive: CVT: Simple Pull-Belt CVT model"""

    IMPROVED_PULL_BELT_CVT_MODEL = "Automotive: CVT: Improved Pull-Belt CVT model"
    """Automotive: CVT: Improved Pull-Belt CVT model"""

    SIMPLE_PUSH_BELT_CVT_MODEL = "Automotive: CVT: Simple Push-Belt CVT model"
    """Automotive: CVT: Simple Push-Belt CVT model"""

    IMPROVED_PUSH_BELT_CVT_MODEL = "Automotive: CVT: Improved Push-Belt CVT model"
    """Automotive: CVT: Improved Push-Belt CVT model"""

    CAR_TWO_LAYSHAFT_TRANSAXLE_GEARBOX_GEAR_MODEL = (
        "Automotive: Car Two Layshaft Transaxle Gearbox: Gear Model"
    )
    """Automotive: Car Two Layshaft Transaxle Gearbox: Gear Model"""

    CAR_TRANSAXLE_GEARBOX_GEAR_MODEL = "Automotive: Car Transaxle Gearbox: Gear Model"
    """Automotive: Car Transaxle Gearbox: Gear Model"""

    CONCEPT_MAIN_BEARINGS = (
        "Automotive: Car Two Layshaft Transaxle Gearbox: Concept Main Bearings"
    )
    """Automotive: Car Two Layshaft Transaxle Gearbox: Concept Main Bearings"""

    CAR_TWO_LAYSHAFT_TRANSAXLE_GEARBOX_CONCEPT_SYNCHRONISERS = (
        "Automotive: Car Two Layshaft Transaxle Gearbox: Concept Synchronisers"
    )
    """Automotive: Car Two Layshaft Transaxle Gearbox: Concept Synchronisers"""

    CAR_TRANSAXLE_GEARBOX_CONCEPT_SYNCHRONISERS = (
        "Automotive: Car Transaxle Gearbox: Concept Synchronisers"
    )
    """Automotive: Car Transaxle Gearbox: Concept Synchronisers"""

    CAR_TWO_LAYSHAFT_TRANSAXLE_GEARBOX_ROLLING_BEARINGS = (
        "Automotive: Car Two Layshaft Transaxle Gearbox: Rolling Bearings"
    )
    """Automotive: Car Two Layshaft Transaxle Gearbox: Rolling Bearings"""

    CAR_TRANSAXLE_GEARBOX_ROLLING_BEARINGS = (
        "Automotive: Car Transaxle Gearbox: Rolling Bearings"
    )
    """Automotive: Car Transaxle Gearbox: Rolling Bearings"""

    CAR_TWO_LAYSHAFT_TRANSAXLE_GEARBOX_SHAFT_DETAILS = (
        "Automotive: Car Two Layshaft Transaxle Gearbox: Shaft Details"
    )
    """Automotive: Car Two Layshaft Transaxle Gearbox: Shaft Details"""

    CAR_TRANSAXLE_GEARBOX_SHAFT_DETAILS = (
        "Automotive: Car Transaxle Gearbox: Shaft Details"
    )
    """Automotive: Car Transaxle Gearbox: Shaft Details"""

    CAR_AXLE_DRIVELINE = "Automotive: Car Axle & Driveline"
    """Automotive: Car Axle & Driveline"""

    CAR_AXLE = "Automotive: Car Axle"
    """Automotive: Car Axle"""

    GEAR_MODEL_CONCEPT_BEARINGS = (
        "Automotive: Car Transaxle Gearbox: Gear Model + Concept Bearings"
    )
    """Automotive: Car Transaxle Gearbox: Gear Model + Concept Bearings"""

    FULL_MODEL = "Automotive: Car Transaxle Gearbox: Full Model"
    """Automotive: Car Transaxle Gearbox: Full Model"""

    HELICAL_GEAR_SET = "Components: Gear Sets: Helical Gear Set"
    """Components: Gear Sets: Helical Gear Set"""

    TRUCK_AXLE = "Automotive: Truck Axle"
    """Automotive: Truck Axle"""

    AEROSPACE_ACCESSORY_GEARBOX_WITHOUT_FE_PARTS = (
        "Aerospace: Aerospace Accessory Gearbox without FE Parts"
    )
    """Aerospace: Aerospace Accessory Gearbox without FE Parts"""

    AEROSPACE_ACCESSORY_GEARBOX_WITH_FE_PARTS = (
        "Aerospace: Aerospace Accessory Gearbox with FE Parts"
    )
    """Aerospace: Aerospace Accessory Gearbox with FE Parts"""

    AIRCRAFT_NOSE_WHEEL = "Aerospace: Aircraft Nose Wheel"
    """Aerospace: Aircraft Nose Wheel"""

    HELICOPTER_TRANSMISSION = "Aerospace: Helicopter Transmission"
    """Aerospace: Helicopter Transmission"""

    AIRCRAFT_ENGINE = "Aerospace: Aircraft Engine"
    """Aerospace: Aircraft Engine"""

    WORM_GEAR_SET = "Components: Gear Sets: Worm Gear Set"
    """Components: Gear Sets: Worm Gear Set"""

    GEAR_SETS_SPIRAL_BEVEL_GEAR_SET = "Components: Gear Sets: Spiral Bevel Gear Set"
    """Components: Gear Sets: Spiral Bevel Gear Set"""

    BEVEL_LTCA_SPIRAL_BEVEL_GEAR_SET = "Analyses: Bevel LTCA: Spiral Bevel Gear Set"
    """Analyses: Bevel LTCA: Spiral Bevel Gear Set"""

    STRAIGHT_BEVEL_GEAR_SET = "Components: Gear Sets: Straight Bevel Gear Set"
    """Components: Gear Sets: Straight Bevel Gear Set"""

    KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_SET = (
        "Components: Gear Sets: Klingelnberg Cyclo-Palloid Spiral Bevel Gear Set"
    )
    """Components: Gear Sets: Klingelnberg Cyclo-Palloid Spiral Bevel Gear Set"""

    FACE_GEAR_SET = "Components: Gear Sets: Face Gear Set"
    """Components: Gear Sets: Face Gear Set"""

    KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_SET = (
        "Components: Gear Sets: Klingelnberg Cyclo-Palloid Hypoid Gear Set"
    )
    """Components: Gear Sets: Klingelnberg Cyclo-Palloid Hypoid Gear Set"""

    SIMPLE_DYNAMIC_ANGULAR_CONTACT_BALL_BEARING = (
        "Analyses: Rolling Bearings: Simple Dynamic Angular Contact Ball Bearing"
    )
    """Analyses: Rolling Bearings: Simple Dynamic Angular Contact Ball Bearing"""

    PLAIN_JOURNAL_BEARING = "Components: Fluid Film Bearings: Plain Journal Bearing"
    """Components: Fluid Film Bearings: Plain Journal Bearing"""

    TILTING_THRUST_PAD_BEARING = (
        "Components: Fluid Film Bearings: Tilting Thrust Pad Bearing"
    )
    """Components: Fluid Film Bearings: Tilting Thrust Pad Bearing"""

    TILTING_PAD_JOURNAL_BEARING = (
        "Components: Fluid Film Bearings: Tilting Pad Journal Bearing"
    )
    """Components: Fluid Film Bearings: Tilting Pad Journal Bearing"""

    TWO_Z_X_WW = "Components: Planetaries: 2Z-X WW"
    """Components: Planetaries: 2Z-X WW"""

    TWO_Z_X_NN_ONE_PLANET = "Components: Planetaries: 2Z-X NN 1 Planet"
    """Components: Planetaries: 2Z-X NN 1 Planet"""

    TWO_Z_X_NN = "Components: Planetaries: 2Z-X NN"
    """Components: Planetaries: 2Z-X NN"""

    TWO_Z_X_NW = "Components: Planetaries: 2Z-X NW"
    """Components: Planetaries: 2Z-X NW"""

    UNEQUAL_SPACING_IDLER = "Components: Planetaries: Unequal Spacing Idler"
    """Components: Planetaries: Unequal Spacing Idler"""

    CVT = "Components: CVTs: CVT"
    """Components: CVTs: CVT"""

    CVT_WITH_SIMPLE_FE_ANNULUS = "Components: CVTs: CVT - With Simple FE Annulus"
    """Components: CVTs: CVT - With Simple FE Annulus"""

    RANGE_CHANGER = "Components: Planetaries: Range Changer"
    """Components: Planetaries: Range Changer"""

    SIMPLE_PLANETARY_WITH_FE_CARRIER = (
        "Components: Planetaries: Simple Planetary with FE Carrier"
    )
    """Components: Planetaries: Simple Planetary with FE Carrier"""

    SIMPLE_CYCLOIDAL_DRIVE = "Components: Cycloidal Drives: Simple Cycloidal Drive"
    """Components: Cycloidal Drives: Simple Cycloidal Drive"""

    SIMPLE_HOUSING = "Components: Simple Housing"
    """Components: Simple Housing"""

    SIMPLE_HOUSING_FULL_MESH = "Components: Simple Housing Full Mesh"
    """Components: Simple Housing Full Mesh"""

    PARKING_LOCK_TRAINING_MODEL = "Components: Parking Lock Training Model"
    """Components: Parking Lock Training Model"""

    SIMPLE_HOUSING_FULL_MESH_FOR_ACOUSTICS = (
        "Analyses: Acoustics: Simple Housing Full Mesh for Acoustics"
    )
    """Analyses: Acoustics: Simple Housing Full Mesh for Acoustics"""

    HIGH_ASYMMETRY_RATIO_GEAR_EXAMPLE = (
        "Analyses: LTCA: High Asymmetry Ratio Gear Example"
    )
    """Analyses: LTCA: High Asymmetry Ratio Gear Example"""

    TRUCK_GEAR_PAIR_FE_MODEL_ZERO_ADJ_TEETH = (
        "Analyses: LTCA: Truck Gear Pair, FE Model, 0 Adj. Teeth"
    )
    """Analyses: LTCA: Truck Gear Pair, FE Model, 0 Adj. Teeth"""

    MARINE_GEAR_PAIR_FE_MODEL_ZERO_ADJ_TEETH = (
        "Analyses: LTCA: Marine Gear Pair, FE Model, 0 Adj. Teeth"
    )
    """Analyses: LTCA: Marine Gear Pair, FE Model, 0 Adj. Teeth"""

    ROTOR_DYNAMICS_TWO_SHAFTS = "Analyses: Rotor Dynamics: Rotor Dynamics Two Shafts"
    """Analyses: Rotor Dynamics: Rotor Dynamics Two Shafts"""

    ROTOR_DYNAMICS_TWO_SHAFTS_FULL_MODEL = (
        "Analyses: Rotor Dynamics: Rotor Dynamics Two Shafts - Full Model"
    )
    """Analyses: Rotor Dynamics: Rotor Dynamics Two Shafts - Full Model"""

    LAVEL_JEFFCOTT_ROTOR = "Analyses: Rotor Dynamics: Lavel Jeffcott Rotor"
    """Analyses: Rotor Dynamics: Lavel Jeffcott Rotor"""

    COMPLETE_CYLINDRICAL_GEAR_PAIR = (
        "Analyses: Cylindrical Gear Manufacturing: Complete Cylindrical Gear Pair"
    )
    """Analyses: Cylindrical Gear Manufacturing: Complete Cylindrical Gear Pair"""

    CYLINDRICAL_PLANETARY = (
        "Analyses: Cylindrical Gear Manufacturing: Cylindrical Planetary"
    )
    """Analyses: Cylindrical Gear Manufacturing: Cylindrical Planetary"""

    INTERNAL_GEAR_PAIR_FE_MODEL_ZERO_ADJ_TEETH = (
        "Analyses: LTCA: Internal Gear Pair, FE Model, 0 Adj. Teeth"
    )
    """Analyses: LTCA: Internal Gear Pair, FE Model, 0 Adj. Teeth"""

    MACK_ALDENER_SINGLE_STAGE = "Analyses: TIFF: MackAldener Single Stage"
    """Analyses: TIFF: MackAldener Single Stage"""

    MACK_ALDENER_IDLER = "Analyses: TIFF: MackAldener Idler"
    """Analyses: TIFF: MackAldener Idler"""

    FZG_TYPE_C_OPTIMISATION_EXAMPLE = (
        "Analyses: Macro Geometry Optimisation: FZG Type C - Optimisation Example"
    )
    """Analyses: Macro Geometry Optimisation: FZG Type C - Optimisation Example"""

    MULTI_MODE_HYBRID_TRANSMISSION = (
        "Automotive: Hybrid Transmission Examples: Multi Mode Hybrid Transmission"
    )
    """Automotive: Hybrid Transmission Examples: Multi Mode Hybrid Transmission"""

    MINIVAN_AXLE_NO_FE = "Automotive: Minivan Axle and Driveline: Minivan Axle no FE"
    """Automotive: Minivan Axle and Driveline: Minivan Axle no FE"""

    MINIVAN_AXLE_CASING_FE = (
        "Automotive: Minivan Axle and Driveline: Minivan Axle + Casing FE"
    )
    """Automotive: Minivan Axle and Driveline: Minivan Axle + Casing FE"""

    MINIVAN_AXLE_CASING_AND_DIFF_SHAFT_FE = "Automotive: Minivan Axle and Driveline: Minivan Axle + Casing and Diff Shaft FE"
    """Automotive: Minivan Axle and Driveline: Minivan Axle + Casing and Diff Shaft FE"""

    FULL_MODEL_DIFF_FE = "Automotive: Car Transaxle Gearbox: Full Model + Diff FE"
    """Automotive: Car Transaxle Gearbox: Full Model + Diff FE"""

    FULL_MODEL_DIFF_INTERNALS = (
        "Automotive: Car Transaxle Gearbox: Full Model + Diff Internals"
    )
    """Automotive: Car Transaxle Gearbox: Full Model + Diff Internals"""

    FULL_MODEL_DIFF_SHAFT_FE_DIFF_INTERNALS = (
        "Automotive: Car Transaxle Gearbox: Full Model + Diff Shaft FE + Diff Internals"
    )
    """Automotive: Car Transaxle Gearbox: Full Model + Diff Shaft FE + Diff Internals"""

    FULL_MODEL_DIFF_SHAFT_FE_DIFF_INTERNALS_PIN_FE = "Automotive: Car Transaxle Gearbox: Full Model + Diff Shaft FE + Diff Internals + Pin FE"
    """Automotive: Car Transaxle Gearbox: Full Model + Diff Shaft FE + Diff Internals + Pin FE"""

    AUTOMATIC_WITH_RAVIGNEAUX = (
        "Automotive: Automatic with Ravigneaux: Automatic with Ravigneaux"
    )
    """Automotive: Automatic with Ravigneaux: Automatic with Ravigneaux"""

    TRANSFER_CASE_BELT = "Automotive: Transfer Case - Belt"
    """Automotive: Transfer Case - Belt"""

    ELECTRIC_DRIVE_TRANSMISSION = (
        "Automotive: Electric Drive Transmission: Electric Drive Transmission"
    )
    """Automotive: Electric Drive Transmission: Electric Drive Transmission"""

    ELECTRIC_DRIVE_TRANSMISSION_WITH_ELECTRIC_MOTOR = "Automotive: Electric Drive Transmission: Electric Drive Transmission - With Electric Motor"
    """Automotive: Electric Drive Transmission: Electric Drive Transmission - With Electric Motor"""

    ELECTRIC_DRIVE_TRANSMISSION_DETAILED_MODEL = "Automotive: Electric Drive Transmission: Electric Drive Transmission - Detailed Model"
    """Automotive: Electric Drive Transmission: Electric Drive Transmission - Detailed Model"""

    ELECTRIC_DRIVE_TRANSMISSION_DETAILED_MODEL_NO_HOUSING_NO_DIFF_INTERNALS = "Automotive: Electric Drive Transmission: Electric Drive Transmission - Detailed Model - No Housing, No Diff Internals"
    """Automotive: Electric Drive Transmission: Electric Drive Transmission - Detailed Model - No Housing, No Diff Internals"""

    ELECTRIC_DRIVE_TRANSMISSION_SKEWED_ROTOR = "Automotive: Electric Drive Transmission: Electric Drive Transmission - Skewed Rotor"
    """Automotive: Electric Drive Transmission: Electric Drive Transmission - Skewed Rotor"""

    ELECTRIC_DRIVE_TRANSMISSION_AXIAL_FLUX_MOTOR = "Automotive: Electric Drive Transmission: Electric Drive Transmission - Axial Flux Motor"
    """Automotive: Electric Drive Transmission: Electric Drive Transmission - Axial Flux Motor"""

    TRANSFER_CASE_GEAR = "Automotive: Transfer Case - Gear"
    """Automotive: Transfer Case - Gear"""

    AUTOMATIC_WITH_RAVIGNEAUX_WITH_CARRIER_FE = "Automotive: Automatic with Ravigneaux: Automatic with Ravigneaux, with Carrier FE"
    """Automotive: Automatic with Ravigneaux: Automatic with Ravigneaux, with Carrier FE"""

    PLANETARY_RANGE_CHANGER = (
        "Automotive: Drive Train Simulation: Planetary Range Changer"
    )
    """Automotive: Drive Train Simulation: Planetary Range Changer"""

    TWO_SHAFTS_ONE_CLUTCH = "Automotive: Drive Train Simulation: Two Shafts One Clutch"
    """Automotive: Drive Train Simulation: Two Shafts One Clutch"""

    TORQUE_CONVERTER = "Automotive: Drive Train Simulation: Torque Converter"
    """Automotive: Drive Train Simulation: Torque Converter"""

    ENGINE_INERTIA_ADJUSTED_LOADS = (
        "Automotive: Drive Train Simulation: Engine - Inertia Adjusted Loads"
    )
    """Automotive: Drive Train Simulation: Engine - Inertia Adjusted Loads"""

    TWO_SPEED_DEMO = "Automotive: Drive Train Simulation: Two Speed Demo"
    """Automotive: Drive Train Simulation: Two Speed Demo"""

    FIVE_DOF_TORSIONAL_MODEL_NO_INPUTS = (
        "Automotive: Gear Rattle Training Manual: 5DOF Torsional Model (No Inputs)"
    )
    """Automotive: Gear Rattle Training Manual: 5DOF Torsional Model (No Inputs)"""

    FIVE_DOF_TORSIONAL_MODEL_COMPLETED_ONE_LASH = "Automotive: Gear Rattle Training Manual: 5DOF Torsional Model (Completed, 1 Lash)"
    """Automotive: Gear Rattle Training Manual: 5DOF Torsional Model (Completed, 1 Lash)"""

    FIVE_DOF_TORSIONAL_MODEL_COMPLETED_TWO_LASH = "Automotive: Gear Rattle Training Manual: 5DOF Torsional Model (Completed, 2 Lash)"
    """Automotive: Gear Rattle Training Manual: 5DOF Torsional Model (Completed, 2 Lash)"""

    SIMPLE_HOUSING_NO_INPUTS = (
        "Automotive: Gear Rattle Training Manual: Simple Housing (No Inputs)"
    )
    """Automotive: Gear Rattle Training Manual: Simple Housing (No Inputs)"""

    SIMPLE_HOUSING_COMPLETED = (
        "Automotive: Gear Rattle Training Manual: Simple Housing (Completed)"
    )
    """Automotive: Gear Rattle Training Manual: Simple Housing (Completed)"""

    SPLINE_RUMBLE = "Automotive: Spline Rumble Training Manual: Spline Rumble"
    """Automotive: Spline Rumble Training Manual: Spline Rumble"""

    WIND_TURBINE_FLEXIBLE_ANNULUS = "Wind Turbine: Wind Turbine - Flexible Annulus"
    """Wind Turbine: Wind Turbine - Flexible Annulus"""

    WIND_TURBINE = "Wind Turbine: Wind Turbine"
    """Wind Turbine: Wind Turbine"""

    WIND_TURBINE_FLEXIBLE_BEARING_OUTER_RACE = (
        "Wind Turbine: Wind Turbine - Flexible Bearing Outer Race"
    )
    """Wind Turbine: Wind Turbine - Flexible Bearing Outer Race"""

    WIND_TURBINE_GEARBOX = "Wind Turbine: Drive Train Simulation: Wind Turbine Gearbox"
    """Wind Turbine: Drive Train Simulation: Wind Turbine Gearbox"""

    WIND_TURBINE_FULL_DRIVETRAIN = (
        "Wind Turbine: Drive Train Simulation: Wind Turbine Full Drivetrain"
    )
    """Wind Turbine: Drive Train Simulation: Wind Turbine Full Drivetrain"""

    ONE_PLANETARY_TWO_PARALLEL_STAGES = (
        "Wind Turbine: Concept Designs: 1 Planetary, 2 Parallel Stages"
    )
    """Wind Turbine: Concept Designs: 1 Planetary, 2 Parallel Stages"""

    ONE_PLANETARY_TWO_PARALLEL_STAGES_WITH_TORQUE_LIMIT_STAGE = "Wind Turbine: Concept Designs: 1 Planetary, 2 Parallel Stages With Torque Limit Stage"
    """Wind Turbine: Concept Designs: 1 Planetary, 2 Parallel Stages With Torque Limit Stage"""

    ONE_PLANETARY_ONE_INTERNAL_STAGE = (
        "Wind Turbine: Concept Designs: 1 Planetary, 1 Internal Stage"
    )
    """Wind Turbine: Concept Designs: 1 Planetary, 1 Internal Stage"""

    TWO_PLANETARY_ONE_PARALLEL_STAGE = (
        "Wind Turbine: Concept Designs: 2 Planetary, 1 Parallel Stage"
    )
    """Wind Turbine: Concept Designs: 2 Planetary, 1 Parallel Stage"""

    THREE_PARALLEL_STAGES = "Wind Turbine: Concept Designs: Three Parallel Stages"
    """Wind Turbine: Concept Designs: Three Parallel Stages"""

    PRIMARY_STEP_UP_BEVEL_PLANETARY_WITH_MOTOR = (
        "Wind Turbine: Concept Designs: Primary Step-up, Bevel, Planetary With Motor"
    )
    """Wind Turbine: Concept Designs: Primary Step-up, Bevel, Planetary With Motor"""

    PLANETARY_DIFF_PLANETARY_STAR_PARALLEL_STAGES = (
        "Wind Turbine: Concept Designs: Planetary Diff, Planetary Star, Parallel Stages"
    )
    """Wind Turbine: Concept Designs: Planetary Diff, Planetary Star, Parallel Stages"""

    PLANETARY_PLANETARY_STAR_PLANETARY_DIFF_PARALLEL_STAGES = "Wind Turbine: Concept Designs: Planetary, Planetary Star, Planetary Diff, Parallel Stages"
    """Wind Turbine: Concept Designs: Planetary, Planetary Star, Planetary Diff, Parallel Stages"""

    ONE_PLANETARY_STAR_TWO_PLANETARY_DIFF_STAGES = (
        "Wind Turbine: Concept Designs: 1 Planetary Star, 2 Planetary Diff Stages"
    )
    """Wind Turbine: Concept Designs: 1 Planetary Star, 2 Planetary Diff Stages"""

    ONE_PLANETARY_TWO_PARALLEL_PLANETARY_DIFF_PLANETARY_STAR_TORQUE_CONVERTER_STAGES = "Wind Turbine: Concept Designs: 1 Planetary, 2 Parallel, Planetary Diff, Planetary Star, Torque Converter Stages"
    """Wind Turbine: Concept Designs: 1 Planetary, 2 Parallel, Planetary Diff, Planetary Star, Torque Converter Stages"""

    TWO_PLANETARY_PLANETARY_HYDROSTATIC_CVT = (
        "Wind Turbine: Concept Designs: 2 Planetary, Planetary Hydrostatic CVT"
    )
    """Wind Turbine: Concept Designs: 2 Planetary, Planetary Hydrostatic CVT"""

    PLANETARY_NO_SUN_PLANETARY_NO_ANNULUS_PARALLEL_STAGE = "Wind Turbine: Concept Designs: Planetary No Sun, Planetary No Annulus, Parallel Stage"
    """Wind Turbine: Concept Designs: Planetary No Sun, Planetary No Annulus, Parallel Stage"""

    TWO_STAGE_COMPOUND_PLANETARY_PARALLEL_STAGE = (
        "Wind Turbine: Concept Designs: 2 Stage Compound Planetary, Parallel Stage"
    )
    """Wind Turbine: Concept Designs: 2 Stage Compound Planetary, Parallel Stage"""

    STARTER_MODEL_CLUTCHED_SYSTEM = "Tutorials: Starter Model - Clutched System"
    """Tutorials: Starter Model - Clutched System"""

    OUTBOARD = "Marine: Outboard"
    """Marine: Outboard"""

    TIDAL_STREAM_GEARBOX = "Marine: Tidal Stream Gearbox"
    """Marine: Tidal Stream Gearbox"""

    RAIL_BOGIE = "Rail: Rail Bogie"
    """Rail: Rail Bogie"""

    WINCH_EXAMPLE = "Industrial: Winch Example"
    """Industrial: Winch Example"""

    RV_CYCLOIDAL_DRIVE_SIMPLE = "Robotics: RV Cycloidal Drive - Simple"
    """Robotics: RV Cycloidal Drive - Simple"""

    RV_CYCLOIDAL_DRIVE_DETAILED = "Robotics: RV Cycloidal Drive - Detailed"
    """Robotics: RV Cycloidal Drive - Detailed"""

    BELT_DRIVE = "Components: Belt Drive"
    """Components: Belt Drive"""

    AGMA_GEAR_SET_FOR_SCUFFING = "Components: Gear Sets: AGMA Gear Set For Scuffing"
    """Components: Gear Sets: AGMA Gear Set For Scuffing"""

    HYPOID_GEAR_SET = "Components: Gear Sets: Hypoid Gear Set"
    """Components: Gear Sets: Hypoid Gear Set"""

    ZEROL_BEVEL_GEAR_SET = "Components: Gear Sets: Zerol Bevel Gear Set"
    """Components: Gear Sets: Zerol Bevel Gear Set"""

    SIMPLE_PLANETARY = "Components: Planetaries: Simple Planetary"
    """Components: Planetaries: Simple Planetary"""

    HIGH_RATIO_COMPOUND = "Components: Planetaries: High Ratio Compound"
    """Components: Planetaries: High Ratio Compound"""

    BEVEL_DIFFERENTIAL_WITH_TWO_CARRIERS = (
        "Components: Planetaries: Bevel Differential with Two Carriers"
    )
    """Components: Planetaries: Bevel Differential with Two Carriers"""

    SCOOTER_GEARBOX = "Automotive: Scooter Gearbox"
    """Automotive: Scooter Gearbox"""

    def load(self: "Self_ExampleName") -> "Design":
        """Load the design."""
        from mastapy.system_model import Design

        return Design.load_example(self)


class Examples(ABC, metaclass=ExamplesMeta):
    """Root of the Examples hierarchy.

    This is designed to simplify loading examples. The easiest way to
    use this class is by calling the load method on the enum itself.

    Alternatively, you can pass the enum directly into Design.load_example().

    Loading design examples with a string is still supported.

    Examples:
        >>> design = Examples.Automotive.SCOOTER_GEARBOX.load()
        >>> design = Design.load_example(Examples.Automotive.SCOOTER_GEARBOX)
    """

    class Automotive(ABC, metaclass=ExamplesMeta):
        """Automotive examples."""

        class CVT(ABC, metaclass=ExamplesMeta):
            """CVT examples."""

            SIMPLE_PULL_BELT_CVT_MODEL = ExampleName.SIMPLE_PULL_BELT_CVT_MODEL
            """Automotive: CVT: Simple Pull-Belt CVT model"""

            IMPROVED_PULL_BELT_CVT_MODEL = ExampleName.IMPROVED_PULL_BELT_CVT_MODEL
            """Automotive: CVT: Improved Pull-Belt CVT model"""

            SIMPLE_PUSH_BELT_CVT_MODEL = ExampleName.SIMPLE_PUSH_BELT_CVT_MODEL
            """Automotive: CVT: Simple Push-Belt CVT model"""

            IMPROVED_PUSH_BELT_CVT_MODEL = ExampleName.IMPROVED_PUSH_BELT_CVT_MODEL
            """Automotive: CVT: Improved Push-Belt CVT model"""

        class CarTwoLayshaftTransaxleGearbox(ABC, metaclass=ExamplesMeta):
            """Car Two Layshaft Transaxle Gearbox examples."""

            GEAR_MODEL = ExampleName.CAR_TWO_LAYSHAFT_TRANSAXLE_GEARBOX_GEAR_MODEL
            """Automotive: Car Two Layshaft Transaxle Gearbox: Gear Model"""

            CONCEPT_MAIN_BEARINGS = ExampleName.CONCEPT_MAIN_BEARINGS
            """Automotive: Car Two Layshaft Transaxle Gearbox: Concept Main Bearings"""

            CONCEPT_SYNCHRONISERS = (
                ExampleName.CAR_TWO_LAYSHAFT_TRANSAXLE_GEARBOX_CONCEPT_SYNCHRONISERS
            )
            """Automotive: Car Two Layshaft Transaxle Gearbox: Concept Synchronisers"""

            ROLLING_BEARINGS = (
                ExampleName.CAR_TWO_LAYSHAFT_TRANSAXLE_GEARBOX_ROLLING_BEARINGS
            )
            """Automotive: Car Two Layshaft Transaxle Gearbox: Rolling Bearings"""

            SHAFT_DETAILS = ExampleName.CAR_TWO_LAYSHAFT_TRANSAXLE_GEARBOX_SHAFT_DETAILS
            """Automotive: Car Two Layshaft Transaxle Gearbox: Shaft Details"""

        class CarTransaxleGearbox(ABC, metaclass=ExamplesMeta):
            """Car Transaxle Gearbox examples."""

            GEAR_MODEL = ExampleName.CAR_TRANSAXLE_GEARBOX_GEAR_MODEL
            """Automotive: Car Transaxle Gearbox: Gear Model"""

            CONCEPT_SYNCHRONISERS = (
                ExampleName.CAR_TRANSAXLE_GEARBOX_CONCEPT_SYNCHRONISERS
            )
            """Automotive: Car Transaxle Gearbox: Concept Synchronisers"""

            ROLLING_BEARINGS = ExampleName.CAR_TRANSAXLE_GEARBOX_ROLLING_BEARINGS
            """Automotive: Car Transaxle Gearbox: Rolling Bearings"""

            SHAFT_DETAILS = ExampleName.CAR_TRANSAXLE_GEARBOX_SHAFT_DETAILS
            """Automotive: Car Transaxle Gearbox: Shaft Details"""

            GEAR_MODEL_CONCEPT_BEARINGS = ExampleName.GEAR_MODEL_CONCEPT_BEARINGS
            """Automotive: Car Transaxle Gearbox: Gear Model + Concept Bearings"""

            FULL_MODEL = ExampleName.FULL_MODEL
            """Automotive: Car Transaxle Gearbox: Full Model"""

            FULL_MODEL_DIFF_FE = ExampleName.FULL_MODEL_DIFF_FE
            """Automotive: Car Transaxle Gearbox: Full Model + Diff FE"""

            FULL_MODEL_DIFF_INTERNALS = ExampleName.FULL_MODEL_DIFF_INTERNALS
            """Automotive: Car Transaxle Gearbox: Full Model + Diff Internals"""

            FULL_MODEL_DIFF_SHAFT_FE_DIFF_INTERNALS = (
                ExampleName.FULL_MODEL_DIFF_SHAFT_FE_DIFF_INTERNALS
            )
            """Automotive: Car Transaxle Gearbox: Full Model + Diff Shaft FE + Diff Internals"""

            FULL_MODEL_DIFF_SHAFT_FE_DIFF_INTERNALS_PIN_FE = (
                ExampleName.FULL_MODEL_DIFF_SHAFT_FE_DIFF_INTERNALS_PIN_FE
            )
            """Automotive: Car Transaxle Gearbox: Full Model + Diff Shaft FE + Diff Internals + Pin FE"""

        CAR_AXLE_DRIVELINE = ExampleName.CAR_AXLE_DRIVELINE
        """Automotive: Car Axle & Driveline"""

        CAR_AXLE = ExampleName.CAR_AXLE
        """Automotive: Car Axle"""

        TRUCK_AXLE = ExampleName.TRUCK_AXLE
        """Automotive: Truck Axle"""

        class HybridTransmissionExamples(ABC, metaclass=ExamplesMeta):
            """Hybrid Transmission Examples examples."""

            MULTI_MODE_HYBRID_TRANSMISSION = ExampleName.MULTI_MODE_HYBRID_TRANSMISSION
            """Automotive: Hybrid Transmission Examples: Multi Mode Hybrid Transmission"""

        class MinivanAxleAndDriveline(ABC, metaclass=ExamplesMeta):
            """Minivan Axle and Driveline examples."""

            MINIVAN_AXLE_NO_FE = ExampleName.MINIVAN_AXLE_NO_FE
            """Automotive: Minivan Axle and Driveline: Minivan Axle no FE"""

            MINIVAN_AXLE_CASING_FE = ExampleName.MINIVAN_AXLE_CASING_FE
            """Automotive: Minivan Axle and Driveline: Minivan Axle + Casing FE"""

            MINIVAN_AXLE_CASING_AND_DIFF_SHAFT_FE = (
                ExampleName.MINIVAN_AXLE_CASING_AND_DIFF_SHAFT_FE
            )
            """Automotive: Minivan Axle and Driveline: Minivan Axle + Casing and Diff Shaft FE"""

        class AutomaticWithRavigneaux(ABC, metaclass=ExamplesMeta):
            """Automatic with Ravigneaux examples."""

            AUTOMATIC_WITH_RAVIGNEAUX = ExampleName.AUTOMATIC_WITH_RAVIGNEAUX
            """Automotive: Automatic with Ravigneaux: Automatic with Ravigneaux"""

            AUTOMATIC_WITH_RAVIGNEAUX_WITH_CARRIER_FE = (
                ExampleName.AUTOMATIC_WITH_RAVIGNEAUX_WITH_CARRIER_FE
            )
            """Automotive: Automatic with Ravigneaux: Automatic with Ravigneaux, with Carrier FE"""

        TRANSFER_CASE_BELT = ExampleName.TRANSFER_CASE_BELT
        """Automotive: Transfer Case - Belt"""

        class ElectricDriveTransmission(ABC, metaclass=ExamplesMeta):
            """Electric Drive Transmission examples."""

            ELECTRIC_DRIVE_TRANSMISSION = ExampleName.ELECTRIC_DRIVE_TRANSMISSION
            """Automotive: Electric Drive Transmission: Electric Drive Transmission"""

            ELECTRIC_DRIVE_TRANSMISSION_WITH_ELECTRIC_MOTOR = (
                ExampleName.ELECTRIC_DRIVE_TRANSMISSION_WITH_ELECTRIC_MOTOR
            )
            """Automotive: Electric Drive Transmission: Electric Drive Transmission - With Electric Motor"""

            ELECTRIC_DRIVE_TRANSMISSION_DETAILED_MODEL = (
                ExampleName.ELECTRIC_DRIVE_TRANSMISSION_DETAILED_MODEL
            )
            """Automotive: Electric Drive Transmission: Electric Drive Transmission - Detailed Model"""

            ELECTRIC_DRIVE_TRANSMISSION_DETAILED_MODEL_NO_HOUSING_NO_DIFF_INTERNALS = ExampleName.ELECTRIC_DRIVE_TRANSMISSION_DETAILED_MODEL_NO_HOUSING_NO_DIFF_INTERNALS
            """Automotive: Electric Drive Transmission: Electric Drive Transmission - Detailed Model - No Housing, No Diff Internals"""

            ELECTRIC_DRIVE_TRANSMISSION_SKEWED_ROTOR = (
                ExampleName.ELECTRIC_DRIVE_TRANSMISSION_SKEWED_ROTOR
            )
            """Automotive: Electric Drive Transmission: Electric Drive Transmission - Skewed Rotor"""

            ELECTRIC_DRIVE_TRANSMISSION_AXIAL_FLUX_MOTOR = (
                ExampleName.ELECTRIC_DRIVE_TRANSMISSION_AXIAL_FLUX_MOTOR
            )
            """Automotive: Electric Drive Transmission: Electric Drive Transmission - Axial Flux Motor"""

        TRANSFER_CASE_GEAR = ExampleName.TRANSFER_CASE_GEAR
        """Automotive: Transfer Case - Gear"""

        class DriveTrainSimulation(ABC, metaclass=ExamplesMeta):
            """Drive Train Simulation examples."""

            PLANETARY_RANGE_CHANGER = ExampleName.PLANETARY_RANGE_CHANGER
            """Automotive: Drive Train Simulation: Planetary Range Changer"""

            TWO_SHAFTS_ONE_CLUTCH = ExampleName.TWO_SHAFTS_ONE_CLUTCH
            """Automotive: Drive Train Simulation: Two Shafts One Clutch"""

            TORQUE_CONVERTER = ExampleName.TORQUE_CONVERTER
            """Automotive: Drive Train Simulation: Torque Converter"""

            ENGINE_INERTIA_ADJUSTED_LOADS = ExampleName.ENGINE_INERTIA_ADJUSTED_LOADS
            """Automotive: Drive Train Simulation: Engine - Inertia Adjusted Loads"""

            TWO_SPEED_DEMO = ExampleName.TWO_SPEED_DEMO
            """Automotive: Drive Train Simulation: Two Speed Demo"""

        class GearRattleTrainingManual(ABC, metaclass=ExamplesMeta):
            """Gear Rattle Training Manual examples."""

            FIVE_DOF_TORSIONAL_MODEL_NO_INPUTS = (
                ExampleName.FIVE_DOF_TORSIONAL_MODEL_NO_INPUTS
            )
            """Automotive: Gear Rattle Training Manual: 5DOF Torsional Model (No Inputs)"""

            FIVE_DOF_TORSIONAL_MODEL_COMPLETED_ONE_LASH = (
                ExampleName.FIVE_DOF_TORSIONAL_MODEL_COMPLETED_ONE_LASH
            )
            """Automotive: Gear Rattle Training Manual: 5DOF Torsional Model (Completed, 1 Lash)"""

            FIVE_DOF_TORSIONAL_MODEL_COMPLETED_TWO_LASH = (
                ExampleName.FIVE_DOF_TORSIONAL_MODEL_COMPLETED_TWO_LASH
            )
            """Automotive: Gear Rattle Training Manual: 5DOF Torsional Model (Completed, 2 Lash)"""

            SIMPLE_HOUSING_NO_INPUTS = ExampleName.SIMPLE_HOUSING_NO_INPUTS
            """Automotive: Gear Rattle Training Manual: Simple Housing (No Inputs)"""

            SIMPLE_HOUSING_COMPLETED = ExampleName.SIMPLE_HOUSING_COMPLETED
            """Automotive: Gear Rattle Training Manual: Simple Housing (Completed)"""

        class SplineRumbleTrainingManual(ABC, metaclass=ExamplesMeta):
            """Spline Rumble Training Manual examples."""

            SPLINE_RUMBLE = ExampleName.SPLINE_RUMBLE
            """Automotive: Spline Rumble Training Manual: Spline Rumble"""

        SCOOTER_GEARBOX = ExampleName.SCOOTER_GEARBOX
        """Automotive: Scooter Gearbox"""

    class Components(ABC, metaclass=ExamplesMeta):
        """Components examples."""

        class GearSets(ABC, metaclass=ExamplesMeta):
            """Gear Sets examples."""

            HELICAL_GEAR_SET = ExampleName.HELICAL_GEAR_SET
            """Components: Gear Sets: Helical Gear Set"""

            WORM_GEAR_SET = ExampleName.WORM_GEAR_SET
            """Components: Gear Sets: Worm Gear Set"""

            SPIRAL_BEVEL_GEAR_SET = ExampleName.GEAR_SETS_SPIRAL_BEVEL_GEAR_SET
            """Components: Gear Sets: Spiral Bevel Gear Set"""

            STRAIGHT_BEVEL_GEAR_SET = ExampleName.STRAIGHT_BEVEL_GEAR_SET
            """Components: Gear Sets: Straight Bevel Gear Set"""

            KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_SET = (
                ExampleName.KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_SET
            )
            """Components: Gear Sets: Klingelnberg Cyclo-Palloid Spiral Bevel Gear Set"""

            FACE_GEAR_SET = ExampleName.FACE_GEAR_SET
            """Components: Gear Sets: Face Gear Set"""

            KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_SET = (
                ExampleName.KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_SET
            )
            """Components: Gear Sets: Klingelnberg Cyclo-Palloid Hypoid Gear Set"""

            AGMA_GEAR_SET_FOR_SCUFFING = ExampleName.AGMA_GEAR_SET_FOR_SCUFFING
            """Components: Gear Sets: AGMA Gear Set For Scuffing"""

            HYPOID_GEAR_SET = ExampleName.HYPOID_GEAR_SET
            """Components: Gear Sets: Hypoid Gear Set"""

            ZEROL_BEVEL_GEAR_SET = ExampleName.ZEROL_BEVEL_GEAR_SET
            """Components: Gear Sets: Zerol Bevel Gear Set"""

        class FluidFilmBearings(ABC, metaclass=ExamplesMeta):
            """Fluid Film Bearings examples."""

            PLAIN_JOURNAL_BEARING = ExampleName.PLAIN_JOURNAL_BEARING
            """Components: Fluid Film Bearings: Plain Journal Bearing"""

            TILTING_THRUST_PAD_BEARING = ExampleName.TILTING_THRUST_PAD_BEARING
            """Components: Fluid Film Bearings: Tilting Thrust Pad Bearing"""

            TILTING_PAD_JOURNAL_BEARING = ExampleName.TILTING_PAD_JOURNAL_BEARING
            """Components: Fluid Film Bearings: Tilting Pad Journal Bearing"""

        class Planetaries(ABC, metaclass=ExamplesMeta):
            """Planetaries examples."""

            TWO_Z_X_WW = ExampleName.TWO_Z_X_WW
            """Components: Planetaries: 2Z-X WW"""

            TWO_Z_X_NN_ONE_PLANET = ExampleName.TWO_Z_X_NN_ONE_PLANET
            """Components: Planetaries: 2Z-X NN 1 Planet"""

            TWO_Z_X_NN = ExampleName.TWO_Z_X_NN
            """Components: Planetaries: 2Z-X NN"""

            TWO_Z_X_NW = ExampleName.TWO_Z_X_NW
            """Components: Planetaries: 2Z-X NW"""

            UNEQUAL_SPACING_IDLER = ExampleName.UNEQUAL_SPACING_IDLER
            """Components: Planetaries: Unequal Spacing Idler"""

            RANGE_CHANGER = ExampleName.RANGE_CHANGER
            """Components: Planetaries: Range Changer"""

            SIMPLE_PLANETARY_WITH_FE_CARRIER = (
                ExampleName.SIMPLE_PLANETARY_WITH_FE_CARRIER
            )
            """Components: Planetaries: Simple Planetary with FE Carrier"""

            SIMPLE_PLANETARY = ExampleName.SIMPLE_PLANETARY
            """Components: Planetaries: Simple Planetary"""

            HIGH_RATIO_COMPOUND = ExampleName.HIGH_RATIO_COMPOUND
            """Components: Planetaries: High Ratio Compound"""

            BEVEL_DIFFERENTIAL_WITH_TWO_CARRIERS = (
                ExampleName.BEVEL_DIFFERENTIAL_WITH_TWO_CARRIERS
            )
            """Components: Planetaries: Bevel Differential with Two Carriers"""

        class CVTs(ABC, metaclass=ExamplesMeta):
            """CVTs examples."""

            CVT = ExampleName.CVT
            """Components: CVTs: CVT"""

            CVT_WITH_SIMPLE_FE_ANNULUS = ExampleName.CVT_WITH_SIMPLE_FE_ANNULUS
            """Components: CVTs: CVT - With Simple FE Annulus"""

        class CycloidalDrives(ABC, metaclass=ExamplesMeta):
            """Cycloidal Drives examples."""

            SIMPLE_CYCLOIDAL_DRIVE = ExampleName.SIMPLE_CYCLOIDAL_DRIVE
            """Components: Cycloidal Drives: Simple Cycloidal Drive"""

        SIMPLE_HOUSING = ExampleName.SIMPLE_HOUSING
        """Components: Simple Housing"""

        SIMPLE_HOUSING_FULL_MESH = ExampleName.SIMPLE_HOUSING_FULL_MESH
        """Components: Simple Housing Full Mesh"""

        PARKING_LOCK_TRAINING_MODEL = ExampleName.PARKING_LOCK_TRAINING_MODEL
        """Components: Parking Lock Training Model"""

        BELT_DRIVE = ExampleName.BELT_DRIVE
        """Components: Belt Drive"""

    class Aerospace(ABC, metaclass=ExamplesMeta):
        """Aerospace examples."""

        AEROSPACE_ACCESSORY_GEARBOX_WITHOUT_FE_PARTS = (
            ExampleName.AEROSPACE_ACCESSORY_GEARBOX_WITHOUT_FE_PARTS
        )
        """Aerospace: Aerospace Accessory Gearbox without FE Parts"""

        AEROSPACE_ACCESSORY_GEARBOX_WITH_FE_PARTS = (
            ExampleName.AEROSPACE_ACCESSORY_GEARBOX_WITH_FE_PARTS
        )
        """Aerospace: Aerospace Accessory Gearbox with FE Parts"""

        AIRCRAFT_NOSE_WHEEL = ExampleName.AIRCRAFT_NOSE_WHEEL
        """Aerospace: Aircraft Nose Wheel"""

        HELICOPTER_TRANSMISSION = ExampleName.HELICOPTER_TRANSMISSION
        """Aerospace: Helicopter Transmission"""

        AIRCRAFT_ENGINE = ExampleName.AIRCRAFT_ENGINE
        """Aerospace: Aircraft Engine"""

    class Analyses(ABC, metaclass=ExamplesMeta):
        """Analyses examples."""

        class BevelLTCA(ABC, metaclass=ExamplesMeta):
            """Bevel LTCA examples."""

            SPIRAL_BEVEL_GEAR_SET = ExampleName.BEVEL_LTCA_SPIRAL_BEVEL_GEAR_SET
            """Analyses: Bevel LTCA: Spiral Bevel Gear Set"""

        class RollingBearings(ABC, metaclass=ExamplesMeta):
            """Rolling Bearings examples."""

            SIMPLE_DYNAMIC_ANGULAR_CONTACT_BALL_BEARING = (
                ExampleName.SIMPLE_DYNAMIC_ANGULAR_CONTACT_BALL_BEARING
            )
            """Analyses: Rolling Bearings: Simple Dynamic Angular Contact Ball Bearing"""

        class Acoustics(ABC, metaclass=ExamplesMeta):
            """Acoustics examples."""

            SIMPLE_HOUSING_FULL_MESH_FOR_ACOUSTICS = (
                ExampleName.SIMPLE_HOUSING_FULL_MESH_FOR_ACOUSTICS
            )
            """Analyses: Acoustics: Simple Housing Full Mesh for Acoustics"""

        class LTCA(ABC, metaclass=ExamplesMeta):
            """LTCA examples."""

            HIGH_ASYMMETRY_RATIO_GEAR_EXAMPLE = (
                ExampleName.HIGH_ASYMMETRY_RATIO_GEAR_EXAMPLE
            )
            """Analyses: LTCA: High Asymmetry Ratio Gear Example"""

            TRUCK_GEAR_PAIR_FE_MODEL_ZERO_ADJ_TEETH = (
                ExampleName.TRUCK_GEAR_PAIR_FE_MODEL_ZERO_ADJ_TEETH
            )
            """Analyses: LTCA: Truck Gear Pair, FE Model, 0 Adj. Teeth"""

            MARINE_GEAR_PAIR_FE_MODEL_ZERO_ADJ_TEETH = (
                ExampleName.MARINE_GEAR_PAIR_FE_MODEL_ZERO_ADJ_TEETH
            )
            """Analyses: LTCA: Marine Gear Pair, FE Model, 0 Adj. Teeth"""

            INTERNAL_GEAR_PAIR_FE_MODEL_ZERO_ADJ_TEETH = (
                ExampleName.INTERNAL_GEAR_PAIR_FE_MODEL_ZERO_ADJ_TEETH
            )
            """Analyses: LTCA: Internal Gear Pair, FE Model, 0 Adj. Teeth"""

        class RotorDynamics(ABC, metaclass=ExamplesMeta):
            """Rotor Dynamics examples."""

            ROTOR_DYNAMICS_TWO_SHAFTS = ExampleName.ROTOR_DYNAMICS_TWO_SHAFTS
            """Analyses: Rotor Dynamics: Rotor Dynamics Two Shafts"""

            ROTOR_DYNAMICS_TWO_SHAFTS_FULL_MODEL = (
                ExampleName.ROTOR_DYNAMICS_TWO_SHAFTS_FULL_MODEL
            )
            """Analyses: Rotor Dynamics: Rotor Dynamics Two Shafts - Full Model"""

            LAVEL_JEFFCOTT_ROTOR = ExampleName.LAVEL_JEFFCOTT_ROTOR
            """Analyses: Rotor Dynamics: Lavel Jeffcott Rotor"""

        class CylindricalGearManufacturing(ABC, metaclass=ExamplesMeta):
            """Cylindrical Gear Manufacturing examples."""

            COMPLETE_CYLINDRICAL_GEAR_PAIR = ExampleName.COMPLETE_CYLINDRICAL_GEAR_PAIR
            """Analyses: Cylindrical Gear Manufacturing: Complete Cylindrical Gear Pair"""

            CYLINDRICAL_PLANETARY = ExampleName.CYLINDRICAL_PLANETARY
            """Analyses: Cylindrical Gear Manufacturing: Cylindrical Planetary"""

        class TIFF(ABC, metaclass=ExamplesMeta):
            """TIFF examples."""

            MACK_ALDENER_SINGLE_STAGE = ExampleName.MACK_ALDENER_SINGLE_STAGE
            """Analyses: TIFF: MackAldener Single Stage"""

            MACK_ALDENER_IDLER = ExampleName.MACK_ALDENER_IDLER
            """Analyses: TIFF: MackAldener Idler"""

        class MacroGeometryOptimisation(ABC, metaclass=ExamplesMeta):
            """Macro Geometry Optimisation examples."""

            FZG_TYPE_C_OPTIMISATION_EXAMPLE = (
                ExampleName.FZG_TYPE_C_OPTIMISATION_EXAMPLE
            )
            """Analyses: Macro Geometry Optimisation: FZG Type C - Optimisation Example"""

    class WindTurbine(ABC, metaclass=ExamplesMeta):
        """Wind Turbine examples."""

        WIND_TURBINE_FLEXIBLE_ANNULUS = ExampleName.WIND_TURBINE_FLEXIBLE_ANNULUS
        """Wind Turbine: Wind Turbine - Flexible Annulus"""

        WIND_TURBINE = ExampleName.WIND_TURBINE
        """Wind Turbine: Wind Turbine"""

        WIND_TURBINE_FLEXIBLE_BEARING_OUTER_RACE = (
            ExampleName.WIND_TURBINE_FLEXIBLE_BEARING_OUTER_RACE
        )
        """Wind Turbine: Wind Turbine - Flexible Bearing Outer Race"""

        class DriveTrainSimulation(ABC, metaclass=ExamplesMeta):
            """Drive Train Simulation examples."""

            WIND_TURBINE_GEARBOX = ExampleName.WIND_TURBINE_GEARBOX
            """Wind Turbine: Drive Train Simulation: Wind Turbine Gearbox"""

            WIND_TURBINE_FULL_DRIVETRAIN = ExampleName.WIND_TURBINE_FULL_DRIVETRAIN
            """Wind Turbine: Drive Train Simulation: Wind Turbine Full Drivetrain"""

        class ConceptDesigns(ABC, metaclass=ExamplesMeta):
            """Concept Designs examples."""

            ONE_PLANETARY_TWO_PARALLEL_STAGES = (
                ExampleName.ONE_PLANETARY_TWO_PARALLEL_STAGES
            )
            """Wind Turbine: Concept Designs: 1 Planetary, 2 Parallel Stages"""

            ONE_PLANETARY_TWO_PARALLEL_STAGES_WITH_TORQUE_LIMIT_STAGE = (
                ExampleName.ONE_PLANETARY_TWO_PARALLEL_STAGES_WITH_TORQUE_LIMIT_STAGE
            )
            """Wind Turbine: Concept Designs: 1 Planetary, 2 Parallel Stages With Torque Limit Stage"""

            ONE_PLANETARY_ONE_INTERNAL_STAGE = (
                ExampleName.ONE_PLANETARY_ONE_INTERNAL_STAGE
            )
            """Wind Turbine: Concept Designs: 1 Planetary, 1 Internal Stage"""

            TWO_PLANETARY_ONE_PARALLEL_STAGE = (
                ExampleName.TWO_PLANETARY_ONE_PARALLEL_STAGE
            )
            """Wind Turbine: Concept Designs: 2 Planetary, 1 Parallel Stage"""

            THREE_PARALLEL_STAGES = ExampleName.THREE_PARALLEL_STAGES
            """Wind Turbine: Concept Designs: Three Parallel Stages"""

            PRIMARY_STEP_UP_BEVEL_PLANETARY_WITH_MOTOR = (
                ExampleName.PRIMARY_STEP_UP_BEVEL_PLANETARY_WITH_MOTOR
            )
            """Wind Turbine: Concept Designs: Primary Step-up, Bevel, Planetary With Motor"""

            PLANETARY_DIFF_PLANETARY_STAR_PARALLEL_STAGES = (
                ExampleName.PLANETARY_DIFF_PLANETARY_STAR_PARALLEL_STAGES
            )
            """Wind Turbine: Concept Designs: Planetary Diff, Planetary Star, Parallel Stages"""

            PLANETARY_PLANETARY_STAR_PLANETARY_DIFF_PARALLEL_STAGES = (
                ExampleName.PLANETARY_PLANETARY_STAR_PLANETARY_DIFF_PARALLEL_STAGES
            )
            """Wind Turbine: Concept Designs: Planetary, Planetary Star, Planetary Diff, Parallel Stages"""

            ONE_PLANETARY_STAR_TWO_PLANETARY_DIFF_STAGES = (
                ExampleName.ONE_PLANETARY_STAR_TWO_PLANETARY_DIFF_STAGES
            )
            """Wind Turbine: Concept Designs: 1 Planetary Star, 2 Planetary Diff Stages"""

            ONE_PLANETARY_TWO_PARALLEL_PLANETARY_DIFF_PLANETARY_STAR_TORQUE_CONVERTER_STAGES = ExampleName.ONE_PLANETARY_TWO_PARALLEL_PLANETARY_DIFF_PLANETARY_STAR_TORQUE_CONVERTER_STAGES
            """Wind Turbine: Concept Designs: 1 Planetary, 2 Parallel, Planetary Diff, Planetary Star, Torque Converter Stages"""

            TWO_PLANETARY_PLANETARY_HYDROSTATIC_CVT = (
                ExampleName.TWO_PLANETARY_PLANETARY_HYDROSTATIC_CVT
            )
            """Wind Turbine: Concept Designs: 2 Planetary, Planetary Hydrostatic CVT"""

            PLANETARY_NO_SUN_PLANETARY_NO_ANNULUS_PARALLEL_STAGE = (
                ExampleName.PLANETARY_NO_SUN_PLANETARY_NO_ANNULUS_PARALLEL_STAGE
            )
            """Wind Turbine: Concept Designs: Planetary No Sun, Planetary No Annulus, Parallel Stage"""

            TWO_STAGE_COMPOUND_PLANETARY_PARALLEL_STAGE = (
                ExampleName.TWO_STAGE_COMPOUND_PLANETARY_PARALLEL_STAGE
            )
            """Wind Turbine: Concept Designs: 2 Stage Compound Planetary, Parallel Stage"""

    class Tutorials(ABC, metaclass=ExamplesMeta):
        """Tutorials examples."""

        STARTER_MODEL_CLUTCHED_SYSTEM = ExampleName.STARTER_MODEL_CLUTCHED_SYSTEM
        """Tutorials: Starter Model - Clutched System"""

    class Marine(ABC, metaclass=ExamplesMeta):
        """Marine examples."""

        OUTBOARD = ExampleName.OUTBOARD
        """Marine: Outboard"""

        TIDAL_STREAM_GEARBOX = ExampleName.TIDAL_STREAM_GEARBOX
        """Marine: Tidal Stream Gearbox"""

    class Rail(ABC, metaclass=ExamplesMeta):
        """Rail examples."""

        RAIL_BOGIE = ExampleName.RAIL_BOGIE
        """Rail: Rail Bogie"""

    class Industrial(ABC, metaclass=ExamplesMeta):
        """Industrial examples."""

        WINCH_EXAMPLE = ExampleName.WINCH_EXAMPLE
        """Industrial: Winch Example"""

    class Robotics(ABC, metaclass=ExamplesMeta):
        """Robotics examples."""

        RV_CYCLOIDAL_DRIVE_SIMPLE = ExampleName.RV_CYCLOIDAL_DRIVE_SIMPLE
        """Robotics: RV Cycloidal Drive - Simple"""

        RV_CYCLOIDAL_DRIVE_DETAILED = ExampleName.RV_CYCLOIDAL_DRIVE_DETAILED
        """Robotics: RV Cycloidal Drive - Detailed"""



"""AGMAGleasonConicalGearPowerFlow"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.power_flows import _4379

_AGMA_GLEASON_CONICAL_GEAR_POWER_FLOW = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.PowerFlows",
    "AGMAGleasonConicalGearPowerFlow",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7943,
        _7946,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows import (
        _4358,
        _4360,
        _4361,
        _4363,
        _4371,
        _4408,
        _4412,
        _4428,
        _4430,
        _4453,
        _4459,
        _4462,
        _4464,
        _4465,
        _4481,
    )
    from mastapy._private.system_model.part_model.gears import _2795

    Self = TypeVar("Self", bound="AGMAGleasonConicalGearPowerFlow")
    CastSelf = TypeVar(
        "CastSelf",
        bound="AGMAGleasonConicalGearPowerFlow._Cast_AGMAGleasonConicalGearPowerFlow",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AGMAGleasonConicalGearPowerFlow",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AGMAGleasonConicalGearPowerFlow:
    """Special nested class for casting AGMAGleasonConicalGearPowerFlow to subclasses."""

    __parent__: "AGMAGleasonConicalGearPowerFlow"

    @property
    def conical_gear_power_flow(self: "CastSelf") -> "_4379.ConicalGearPowerFlow":
        return self.__parent__._cast(_4379.ConicalGearPowerFlow)

    @property
    def gear_power_flow(self: "CastSelf") -> "_4408.GearPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4408

        return self.__parent__._cast(_4408.GearPowerFlow)

    @property
    def mountable_component_power_flow(
        self: "CastSelf",
    ) -> "_4428.MountableComponentPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4428

        return self.__parent__._cast(_4428.MountableComponentPowerFlow)

    @property
    def component_power_flow(self: "CastSelf") -> "_4371.ComponentPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4371

        return self.__parent__._cast(_4371.ComponentPowerFlow)

    @property
    def part_power_flow(self: "CastSelf") -> "_4430.PartPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4430

        return self.__parent__._cast(_4430.PartPowerFlow)

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7946.PartStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7946,
        )

        return self.__parent__._cast(_7946.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7943.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7943,
        )

        return self.__parent__._cast(_7943.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def bevel_differential_gear_power_flow(
        self: "CastSelf",
    ) -> "_4358.BevelDifferentialGearPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4358

        return self.__parent__._cast(_4358.BevelDifferentialGearPowerFlow)

    @property
    def bevel_differential_planet_gear_power_flow(
        self: "CastSelf",
    ) -> "_4360.BevelDifferentialPlanetGearPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4360

        return self.__parent__._cast(_4360.BevelDifferentialPlanetGearPowerFlow)

    @property
    def bevel_differential_sun_gear_power_flow(
        self: "CastSelf",
    ) -> "_4361.BevelDifferentialSunGearPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4361

        return self.__parent__._cast(_4361.BevelDifferentialSunGearPowerFlow)

    @property
    def bevel_gear_power_flow(self: "CastSelf") -> "_4363.BevelGearPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4363

        return self.__parent__._cast(_4363.BevelGearPowerFlow)

    @property
    def hypoid_gear_power_flow(self: "CastSelf") -> "_4412.HypoidGearPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4412

        return self.__parent__._cast(_4412.HypoidGearPowerFlow)

    @property
    def spiral_bevel_gear_power_flow(
        self: "CastSelf",
    ) -> "_4453.SpiralBevelGearPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4453

        return self.__parent__._cast(_4453.SpiralBevelGearPowerFlow)

    @property
    def straight_bevel_diff_gear_power_flow(
        self: "CastSelf",
    ) -> "_4459.StraightBevelDiffGearPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4459

        return self.__parent__._cast(_4459.StraightBevelDiffGearPowerFlow)

    @property
    def straight_bevel_gear_power_flow(
        self: "CastSelf",
    ) -> "_4462.StraightBevelGearPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4462

        return self.__parent__._cast(_4462.StraightBevelGearPowerFlow)

    @property
    def straight_bevel_planet_gear_power_flow(
        self: "CastSelf",
    ) -> "_4464.StraightBevelPlanetGearPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4464

        return self.__parent__._cast(_4464.StraightBevelPlanetGearPowerFlow)

    @property
    def straight_bevel_sun_gear_power_flow(
        self: "CastSelf",
    ) -> "_4465.StraightBevelSunGearPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4465

        return self.__parent__._cast(_4465.StraightBevelSunGearPowerFlow)

    @property
    def zerol_bevel_gear_power_flow(
        self: "CastSelf",
    ) -> "_4481.ZerolBevelGearPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4481

        return self.__parent__._cast(_4481.ZerolBevelGearPowerFlow)

    @property
    def agma_gleason_conical_gear_power_flow(
        self: "CastSelf",
    ) -> "AGMAGleasonConicalGearPowerFlow":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class AGMAGleasonConicalGearPowerFlow(_4379.ConicalGearPowerFlow):
    """AGMAGleasonConicalGearPowerFlow

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _AGMA_GLEASON_CONICAL_GEAR_POWER_FLOW

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2795.AGMAGleasonConicalGear":
        """mastapy.system_model.part_model.gears.AGMAGleasonConicalGear

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_AGMAGleasonConicalGearPowerFlow":
        """Cast to another type.

        Returns:
            _Cast_AGMAGleasonConicalGearPowerFlow
        """
        return _Cast_AGMAGleasonConicalGearPowerFlow(self)



"""HobbingProcessTotalModificationCalculation"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, utility
from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new import (
    _792,
)

_HOBBING_PROCESS_TOTAL_MODIFICATION_CALCULATION = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.HobbingProcessSimulationNew",
    "HobbingProcessTotalModificationCalculation",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new import (
        _806,
    )
    from mastapy._private.utility_gui.charts import _2104

    Self = TypeVar("Self", bound="HobbingProcessTotalModificationCalculation")
    CastSelf = TypeVar(
        "CastSelf",
        bound="HobbingProcessTotalModificationCalculation._Cast_HobbingProcessTotalModificationCalculation",
    )


__docformat__ = "restructuredtext en"
__all__ = ("HobbingProcessTotalModificationCalculation",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_HobbingProcessTotalModificationCalculation:
    """Special nested class for casting HobbingProcessTotalModificationCalculation to subclasses."""

    __parent__: "HobbingProcessTotalModificationCalculation"

    @property
    def hobbing_process_calculation(
        self: "CastSelf",
    ) -> "_792.HobbingProcessCalculation":
        return self.__parent__._cast(_792.HobbingProcessCalculation)

    @property
    def process_calculation(self: "CastSelf") -> "_806.ProcessCalculation":
        from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new import (
            _806,
        )

        return self.__parent__._cast(_806.ProcessCalculation)

    @property
    def hobbing_process_total_modification_calculation(
        self: "CastSelf",
    ) -> "HobbingProcessTotalModificationCalculation":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class HobbingProcessTotalModificationCalculation(_792.HobbingProcessCalculation):
    """HobbingProcessTotalModificationCalculation

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _HOBBING_PROCESS_TOTAL_MODIFICATION_CALCULATION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def lead_range_max(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "LeadRangeMax")

        if temp is None:
            return 0.0

        return temp

    @lead_range_max.setter
    @exception_bridge
    @enforce_parameter_types
    def lead_range_max(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "LeadRangeMax", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def lead_range_min(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "LeadRangeMin")

        if temp is None:
            return 0.0

        return temp

    @lead_range_min.setter
    @exception_bridge
    @enforce_parameter_types
    def lead_range_min(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "LeadRangeMin", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def number_of_lead_bands(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "NumberOfLeadBands")

        if temp is None:
            return 0

        return temp

    @number_of_lead_bands.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_lead_bands(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped, "NumberOfLeadBands", int(value) if value is not None else 0
        )

    @property
    @exception_bridge
    def number_of_profile_bands(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "NumberOfProfileBands")

        if temp is None:
            return 0

        return temp

    @number_of_profile_bands.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_profile_bands(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped, "NumberOfProfileBands", int(value) if value is not None else 0
        )

    @property
    @exception_bridge
    def total_errors_chart_left_flank(self: "Self") -> "_2104.ThreeDChartDefinition":
        """mastapy.utility_gui.charts.ThreeDChartDefinition

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TotalErrorsChartLeftFlank")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def total_errors_chart_right_flank(self: "Self") -> "_2104.ThreeDChartDefinition":
        """mastapy.utility_gui.charts.ThreeDChartDefinition

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TotalErrorsChartRightFlank")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_HobbingProcessTotalModificationCalculation":
        """Cast to another type.

        Returns:
            _Cast_HobbingProcessTotalModificationCalculation
        """
        return _Cast_HobbingProcessTotalModificationCalculation(self)



"""ConceptGearSetModalAnalysisAtAStiffness"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
    _5246,
)

_CONCEPT_GEAR_SET_MODAL_ANALYSIS_AT_A_STIFFNESS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtAStiffness",
    "ConceptGearSetModalAnalysisAtAStiffness",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7943,
        _7946,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
        _5185,
        _5214,
        _5215,
        _5268,
        _5287,
    )
    from mastapy._private.system_model.analyses_and_results.static_loads import _7766
    from mastapy._private.system_model.part_model.gears import _2804

    Self = TypeVar("Self", bound="ConceptGearSetModalAnalysisAtAStiffness")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConceptGearSetModalAnalysisAtAStiffness._Cast_ConceptGearSetModalAnalysisAtAStiffness",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConceptGearSetModalAnalysisAtAStiffness",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConceptGearSetModalAnalysisAtAStiffness:
    """Special nested class for casting ConceptGearSetModalAnalysisAtAStiffness to subclasses."""

    __parent__: "ConceptGearSetModalAnalysisAtAStiffness"

    @property
    def gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5246.GearSetModalAnalysisAtAStiffness":
        return self.__parent__._cast(_5246.GearSetModalAnalysisAtAStiffness)

    @property
    def specialised_assembly_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5287.SpecialisedAssemblyModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5287,
        )

        return self.__parent__._cast(_5287.SpecialisedAssemblyModalAnalysisAtAStiffness)

    @property
    def abstract_assembly_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5185.AbstractAssemblyModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5185,
        )

        return self.__parent__._cast(_5185.AbstractAssemblyModalAnalysisAtAStiffness)

    @property
    def part_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5268.PartModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5268,
        )

        return self.__parent__._cast(_5268.PartModalAnalysisAtAStiffness)

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7946.PartStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7946,
        )

        return self.__parent__._cast(_7946.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7943.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7943,
        )

        return self.__parent__._cast(_7943.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def concept_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "ConceptGearSetModalAnalysisAtAStiffness":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ConceptGearSetModalAnalysisAtAStiffness(_5246.GearSetModalAnalysisAtAStiffness):
    """ConceptGearSetModalAnalysisAtAStiffness

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONCEPT_GEAR_SET_MODAL_ANALYSIS_AT_A_STIFFNESS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def assembly_design(self: "Self") -> "_2804.ConceptGearSet":
        """mastapy.system_model.part_model.gears.ConceptGearSet

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def assembly_load_case(self: "Self") -> "_7766.ConceptGearSetLoadCase":
        """mastapy.system_model.analyses_and_results.static_loads.ConceptGearSetLoadCase

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyLoadCase")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def gears_modal_analysis_at_a_stiffness(
        self: "Self",
    ) -> "List[_5215.ConceptGearModalAnalysisAtAStiffness]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness.ConceptGearModalAnalysisAtAStiffness]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearsModalAnalysisAtAStiffness")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def concept_gears_modal_analysis_at_a_stiffness(
        self: "Self",
    ) -> "List[_5215.ConceptGearModalAnalysisAtAStiffness]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness.ConceptGearModalAnalysisAtAStiffness]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ConceptGearsModalAnalysisAtAStiffness"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def meshes_modal_analysis_at_a_stiffness(
        self: "Self",
    ) -> "List[_5214.ConceptGearMeshModalAnalysisAtAStiffness]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness.ConceptGearMeshModalAnalysisAtAStiffness]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MeshesModalAnalysisAtAStiffness")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def concept_meshes_modal_analysis_at_a_stiffness(
        self: "Self",
    ) -> "List[_5214.ConceptGearMeshModalAnalysisAtAStiffness]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness.ConceptGearMeshModalAnalysisAtAStiffness]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ConceptMeshesModalAnalysisAtAStiffness"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_ConceptGearSetModalAnalysisAtAStiffness":
        """Cast to another type.

        Returns:
            _Cast_ConceptGearSetModalAnalysisAtAStiffness
        """
        return _Cast_ConceptGearSetModalAnalysisAtAStiffness(self)



"""Module for defining types used in mastapy."""

import os

try:
    from typing import TypeAlias

    PathLike: TypeAlias = str | os.PathLike[str]
except ImportError:
    PathLike = str | os.PathLike[str]



"""MountableComponentLoadCase"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.static_loads import _7760

_MOUNTABLE_COMPONENT_LOAD_CASE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads",
    "MountableComponentLoadCase",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.static_loads import (
        _7736,
        _7742,
        _7745,
        _7748,
        _7749,
        _7750,
        _7756,
        _7762,
        _7764,
        _7767,
        _7773,
        _7775,
        _7779,
        _7784,
        _7789,
        _7807,
        _7813,
        _7828,
        _7835,
        _7838,
        _7841,
        _7844,
        _7845,
        _7851,
        _7853,
        _7855,
        _7860,
        _7863,
        _7864,
        _7865,
        _7870,
        _7874,
        _7876,
        _7880,
        _7884,
        _7886,
        _7889,
        _7892,
        _7893,
        _7894,
        _7896,
        _7897,
        _7902,
        _7903,
        _7908,
        _7909,
        _7910,
        _7913,
    )
    from mastapy._private.system_model.part_model import _2738

    Self = TypeVar("Self", bound="MountableComponentLoadCase")
    CastSelf = TypeVar(
        "CastSelf", bound="MountableComponentLoadCase._Cast_MountableComponentLoadCase"
    )


__docformat__ = "restructuredtext en"
__all__ = ("MountableComponentLoadCase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_MountableComponentLoadCase:
    """Special nested class for casting MountableComponentLoadCase to subclasses."""

    __parent__: "MountableComponentLoadCase"

    @property
    def component_load_case(self: "CastSelf") -> "_7760.ComponentLoadCase":
        return self.__parent__._cast(_7760.ComponentLoadCase)

    @property
    def part_load_case(self: "CastSelf") -> "_7853.PartLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7853,
        )

        return self.__parent__._cast(_7853.PartLoadCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_load_case(
        self: "CastSelf",
    ) -> "_7736.AGMAGleasonConicalGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7736,
        )

        return self.__parent__._cast(_7736.AGMAGleasonConicalGearLoadCase)

    @property
    def bearing_load_case(self: "CastSelf") -> "_7742.BearingLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7742,
        )

        return self.__parent__._cast(_7742.BearingLoadCase)

    @property
    def bevel_differential_gear_load_case(
        self: "CastSelf",
    ) -> "_7745.BevelDifferentialGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7745,
        )

        return self.__parent__._cast(_7745.BevelDifferentialGearLoadCase)

    @property
    def bevel_differential_planet_gear_load_case(
        self: "CastSelf",
    ) -> "_7748.BevelDifferentialPlanetGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7748,
        )

        return self.__parent__._cast(_7748.BevelDifferentialPlanetGearLoadCase)

    @property
    def bevel_differential_sun_gear_load_case(
        self: "CastSelf",
    ) -> "_7749.BevelDifferentialSunGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7749,
        )

        return self.__parent__._cast(_7749.BevelDifferentialSunGearLoadCase)

    @property
    def bevel_gear_load_case(self: "CastSelf") -> "_7750.BevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7750,
        )

        return self.__parent__._cast(_7750.BevelGearLoadCase)

    @property
    def clutch_half_load_case(self: "CastSelf") -> "_7756.ClutchHalfLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7756,
        )

        return self.__parent__._cast(_7756.ClutchHalfLoadCase)

    @property
    def concept_coupling_half_load_case(
        self: "CastSelf",
    ) -> "_7762.ConceptCouplingHalfLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7762,
        )

        return self.__parent__._cast(_7762.ConceptCouplingHalfLoadCase)

    @property
    def concept_gear_load_case(self: "CastSelf") -> "_7764.ConceptGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7764,
        )

        return self.__parent__._cast(_7764.ConceptGearLoadCase)

    @property
    def conical_gear_load_case(self: "CastSelf") -> "_7767.ConicalGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7767,
        )

        return self.__parent__._cast(_7767.ConicalGearLoadCase)

    @property
    def connector_load_case(self: "CastSelf") -> "_7773.ConnectorLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7773,
        )

        return self.__parent__._cast(_7773.ConnectorLoadCase)

    @property
    def coupling_half_load_case(self: "CastSelf") -> "_7775.CouplingHalfLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7775,
        )

        return self.__parent__._cast(_7775.CouplingHalfLoadCase)

    @property
    def cvt_pulley_load_case(self: "CastSelf") -> "_7779.CVTPulleyLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7779,
        )

        return self.__parent__._cast(_7779.CVTPulleyLoadCase)

    @property
    def cylindrical_gear_load_case(self: "CastSelf") -> "_7784.CylindricalGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7784,
        )

        return self.__parent__._cast(_7784.CylindricalGearLoadCase)

    @property
    def cylindrical_planet_gear_load_case(
        self: "CastSelf",
    ) -> "_7789.CylindricalPlanetGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7789,
        )

        return self.__parent__._cast(_7789.CylindricalPlanetGearLoadCase)

    @property
    def face_gear_load_case(self: "CastSelf") -> "_7807.FaceGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7807,
        )

        return self.__parent__._cast(_7807.FaceGearLoadCase)

    @property
    def gear_load_case(self: "CastSelf") -> "_7813.GearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7813,
        )

        return self.__parent__._cast(_7813.GearLoadCase)

    @property
    def hypoid_gear_load_case(self: "CastSelf") -> "_7828.HypoidGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7828,
        )

        return self.__parent__._cast(_7828.HypoidGearLoadCase)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_load_case(
        self: "CastSelf",
    ) -> "_7835.KlingelnbergCycloPalloidConicalGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7835,
        )

        return self.__parent__._cast(_7835.KlingelnbergCycloPalloidConicalGearLoadCase)

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_load_case(
        self: "CastSelf",
    ) -> "_7838.KlingelnbergCycloPalloidHypoidGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7838,
        )

        return self.__parent__._cast(_7838.KlingelnbergCycloPalloidHypoidGearLoadCase)

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_load_case(
        self: "CastSelf",
    ) -> "_7841.KlingelnbergCycloPalloidSpiralBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7841,
        )

        return self.__parent__._cast(
            _7841.KlingelnbergCycloPalloidSpiralBevelGearLoadCase
        )

    @property
    def mass_disc_load_case(self: "CastSelf") -> "_7844.MassDiscLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7844,
        )

        return self.__parent__._cast(_7844.MassDiscLoadCase)

    @property
    def measurement_component_load_case(
        self: "CastSelf",
    ) -> "_7845.MeasurementComponentLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7845,
        )

        return self.__parent__._cast(_7845.MeasurementComponentLoadCase)

    @property
    def oil_seal_load_case(self: "CastSelf") -> "_7851.OilSealLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7851,
        )

        return self.__parent__._cast(_7851.OilSealLoadCase)

    @property
    def part_to_part_shear_coupling_half_load_case(
        self: "CastSelf",
    ) -> "_7855.PartToPartShearCouplingHalfLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7855,
        )

        return self.__parent__._cast(_7855.PartToPartShearCouplingHalfLoadCase)

    @property
    def planet_carrier_load_case(self: "CastSelf") -> "_7860.PlanetCarrierLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7860,
        )

        return self.__parent__._cast(_7860.PlanetCarrierLoadCase)

    @property
    def point_load_load_case(self: "CastSelf") -> "_7863.PointLoadLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7863,
        )

        return self.__parent__._cast(_7863.PointLoadLoadCase)

    @property
    def power_load_load_case(self: "CastSelf") -> "_7864.PowerLoadLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7864,
        )

        return self.__parent__._cast(_7864.PowerLoadLoadCase)

    @property
    def pulley_load_case(self: "CastSelf") -> "_7865.PulleyLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7865,
        )

        return self.__parent__._cast(_7865.PulleyLoadCase)

    @property
    def ring_pins_load_case(self: "CastSelf") -> "_7870.RingPinsLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7870,
        )

        return self.__parent__._cast(_7870.RingPinsLoadCase)

    @property
    def rolling_ring_load_case(self: "CastSelf") -> "_7874.RollingRingLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7874,
        )

        return self.__parent__._cast(_7874.RollingRingLoadCase)

    @property
    def shaft_hub_connection_load_case(
        self: "CastSelf",
    ) -> "_7876.ShaftHubConnectionLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7876,
        )

        return self.__parent__._cast(_7876.ShaftHubConnectionLoadCase)

    @property
    def spiral_bevel_gear_load_case(
        self: "CastSelf",
    ) -> "_7880.SpiralBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7880,
        )

        return self.__parent__._cast(_7880.SpiralBevelGearLoadCase)

    @property
    def spring_damper_half_load_case(
        self: "CastSelf",
    ) -> "_7884.SpringDamperHalfLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7884,
        )

        return self.__parent__._cast(_7884.SpringDamperHalfLoadCase)

    @property
    def straight_bevel_diff_gear_load_case(
        self: "CastSelf",
    ) -> "_7886.StraightBevelDiffGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7886,
        )

        return self.__parent__._cast(_7886.StraightBevelDiffGearLoadCase)

    @property
    def straight_bevel_gear_load_case(
        self: "CastSelf",
    ) -> "_7889.StraightBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7889,
        )

        return self.__parent__._cast(_7889.StraightBevelGearLoadCase)

    @property
    def straight_bevel_planet_gear_load_case(
        self: "CastSelf",
    ) -> "_7892.StraightBevelPlanetGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7892,
        )

        return self.__parent__._cast(_7892.StraightBevelPlanetGearLoadCase)

    @property
    def straight_bevel_sun_gear_load_case(
        self: "CastSelf",
    ) -> "_7893.StraightBevelSunGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7893,
        )

        return self.__parent__._cast(_7893.StraightBevelSunGearLoadCase)

    @property
    def synchroniser_half_load_case(
        self: "CastSelf",
    ) -> "_7894.SynchroniserHalfLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7894,
        )

        return self.__parent__._cast(_7894.SynchroniserHalfLoadCase)

    @property
    def synchroniser_part_load_case(
        self: "CastSelf",
    ) -> "_7896.SynchroniserPartLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7896,
        )

        return self.__parent__._cast(_7896.SynchroniserPartLoadCase)

    @property
    def synchroniser_sleeve_load_case(
        self: "CastSelf",
    ) -> "_7897.SynchroniserSleeveLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7897,
        )

        return self.__parent__._cast(_7897.SynchroniserSleeveLoadCase)

    @property
    def torque_converter_pump_load_case(
        self: "CastSelf",
    ) -> "_7902.TorqueConverterPumpLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7902,
        )

        return self.__parent__._cast(_7902.TorqueConverterPumpLoadCase)

    @property
    def torque_converter_turbine_load_case(
        self: "CastSelf",
    ) -> "_7903.TorqueConverterTurbineLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7903,
        )

        return self.__parent__._cast(_7903.TorqueConverterTurbineLoadCase)

    @property
    def unbalanced_mass_load_case(self: "CastSelf") -> "_7908.UnbalancedMassLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7908,
        )

        return self.__parent__._cast(_7908.UnbalancedMassLoadCase)

    @property
    def virtual_component_load_case(
        self: "CastSelf",
    ) -> "_7909.VirtualComponentLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7909,
        )

        return self.__parent__._cast(_7909.VirtualComponentLoadCase)

    @property
    def worm_gear_load_case(self: "CastSelf") -> "_7910.WormGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7910,
        )

        return self.__parent__._cast(_7910.WormGearLoadCase)

    @property
    def zerol_bevel_gear_load_case(self: "CastSelf") -> "_7913.ZerolBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7913,
        )

        return self.__parent__._cast(_7913.ZerolBevelGearLoadCase)

    @property
    def mountable_component_load_case(self: "CastSelf") -> "MountableComponentLoadCase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class MountableComponentLoadCase(_7760.ComponentLoadCase):
    """MountableComponentLoadCase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _MOUNTABLE_COMPONENT_LOAD_CASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2738.MountableComponent":
        """mastapy.system_model.part_model.MountableComponent

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_MountableComponentLoadCase":
        """Cast to another type.

        Returns:
            _Cast_MountableComponentLoadCase
        """
        return _Cast_MountableComponentLoadCase(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.gears.rating.cylindrical._564 import AGMAScuffingResultsRow
    from mastapy._private.gears.rating.cylindrical._565 import (
        CylindricalGearDesignAndRatingSettings,
    )
    from mastapy._private.gears.rating.cylindrical._566 import (
        CylindricalGearDesignAndRatingSettingsDatabase,
    )
    from mastapy._private.gears.rating.cylindrical._567 import (
        CylindricalGearDesignAndRatingSettingsItem,
    )
    from mastapy._private.gears.rating.cylindrical._568 import (
        CylindricalGearDutyCycleRating,
    )
    from mastapy._private.gears.rating.cylindrical._569 import (
        CylindricalGearFlankDutyCycleRating,
    )
    from mastapy._private.gears.rating.cylindrical._570 import (
        CylindricalGearFlankRating,
    )
    from mastapy._private.gears.rating.cylindrical._571 import CylindricalGearMeshRating
    from mastapy._private.gears.rating.cylindrical._572 import (
        CylindricalGearMicroPittingResults,
    )
    from mastapy._private.gears.rating.cylindrical._573 import CylindricalGearRating
    from mastapy._private.gears.rating.cylindrical._574 import (
        CylindricalGearRatingGeometryDataSource,
    )
    from mastapy._private.gears.rating.cylindrical._575 import (
        CylindricalGearScuffingResults,
    )
    from mastapy._private.gears.rating.cylindrical._576 import (
        CylindricalGearSetDutyCycleRating,
    )
    from mastapy._private.gears.rating.cylindrical._577 import CylindricalGearSetRating
    from mastapy._private.gears.rating.cylindrical._578 import (
        CylindricalGearSingleFlankRating,
    )
    from mastapy._private.gears.rating.cylindrical._579 import (
        CylindricalMeshDutyCycleRating,
    )
    from mastapy._private.gears.rating.cylindrical._580 import (
        CylindricalMeshSingleFlankRating,
    )
    from mastapy._private.gears.rating.cylindrical._581 import (
        CylindricalPlasticGearRatingSettings,
    )
    from mastapy._private.gears.rating.cylindrical._582 import (
        CylindricalPlasticGearRatingSettingsDatabase,
    )
    from mastapy._private.gears.rating.cylindrical._583 import (
        CylindricalPlasticGearRatingSettingsItem,
    )
    from mastapy._private.gears.rating.cylindrical._584 import CylindricalRateableMesh
    from mastapy._private.gears.rating.cylindrical._585 import DynamicFactorMethods
    from mastapy._private.gears.rating.cylindrical._586 import (
        GearBlankFactorCalculationOptions,
    )
    from mastapy._private.gears.rating.cylindrical._587 import ISOScuffingResultsRow
    from mastapy._private.gears.rating.cylindrical._588 import MeshRatingForReports
    from mastapy._private.gears.rating.cylindrical._589 import MicropittingRatingMethod
    from mastapy._private.gears.rating.cylindrical._590 import MicroPittingResultsRow
    from mastapy._private.gears.rating.cylindrical._591 import (
        MisalignmentContactPatternEnhancements,
    )
    from mastapy._private.gears.rating.cylindrical._592 import RatingMethod
    from mastapy._private.gears.rating.cylindrical._593 import (
        ReducedCylindricalGearSetDutyCycleRating,
    )
    from mastapy._private.gears.rating.cylindrical._594 import (
        ScuffingFlashTemperatureRatingMethod,
    )
    from mastapy._private.gears.rating.cylindrical._595 import (
        ScuffingIntegralTemperatureRatingMethod,
    )
    from mastapy._private.gears.rating.cylindrical._596 import ScuffingMethods
    from mastapy._private.gears.rating.cylindrical._597 import ScuffingResultsRow
    from mastapy._private.gears.rating.cylindrical._598 import ScuffingResultsRowGear
    from mastapy._private.gears.rating.cylindrical._599 import TipReliefScuffingOptions
    from mastapy._private.gears.rating.cylindrical._600 import ToothThicknesses
    from mastapy._private.gears.rating.cylindrical._601 import (
        VDI2737SafetyFactorReportingObject,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.rating.cylindrical._564": ["AGMAScuffingResultsRow"],
        "_private.gears.rating.cylindrical._565": [
            "CylindricalGearDesignAndRatingSettings"
        ],
        "_private.gears.rating.cylindrical._566": [
            "CylindricalGearDesignAndRatingSettingsDatabase"
        ],
        "_private.gears.rating.cylindrical._567": [
            "CylindricalGearDesignAndRatingSettingsItem"
        ],
        "_private.gears.rating.cylindrical._568": ["CylindricalGearDutyCycleRating"],
        "_private.gears.rating.cylindrical._569": [
            "CylindricalGearFlankDutyCycleRating"
        ],
        "_private.gears.rating.cylindrical._570": ["CylindricalGearFlankRating"],
        "_private.gears.rating.cylindrical._571": ["CylindricalGearMeshRating"],
        "_private.gears.rating.cylindrical._572": [
            "CylindricalGearMicroPittingResults"
        ],
        "_private.gears.rating.cylindrical._573": ["CylindricalGearRating"],
        "_private.gears.rating.cylindrical._574": [
            "CylindricalGearRatingGeometryDataSource"
        ],
        "_private.gears.rating.cylindrical._575": ["CylindricalGearScuffingResults"],
        "_private.gears.rating.cylindrical._576": ["CylindricalGearSetDutyCycleRating"],
        "_private.gears.rating.cylindrical._577": ["CylindricalGearSetRating"],
        "_private.gears.rating.cylindrical._578": ["CylindricalGearSingleFlankRating"],
        "_private.gears.rating.cylindrical._579": ["CylindricalMeshDutyCycleRating"],
        "_private.gears.rating.cylindrical._580": ["CylindricalMeshSingleFlankRating"],
        "_private.gears.rating.cylindrical._581": [
            "CylindricalPlasticGearRatingSettings"
        ],
        "_private.gears.rating.cylindrical._582": [
            "CylindricalPlasticGearRatingSettingsDatabase"
        ],
        "_private.gears.rating.cylindrical._583": [
            "CylindricalPlasticGearRatingSettingsItem"
        ],
        "_private.gears.rating.cylindrical._584": ["CylindricalRateableMesh"],
        "_private.gears.rating.cylindrical._585": ["DynamicFactorMethods"],
        "_private.gears.rating.cylindrical._586": ["GearBlankFactorCalculationOptions"],
        "_private.gears.rating.cylindrical._587": ["ISOScuffingResultsRow"],
        "_private.gears.rating.cylindrical._588": ["MeshRatingForReports"],
        "_private.gears.rating.cylindrical._589": ["MicropittingRatingMethod"],
        "_private.gears.rating.cylindrical._590": ["MicroPittingResultsRow"],
        "_private.gears.rating.cylindrical._591": [
            "MisalignmentContactPatternEnhancements"
        ],
        "_private.gears.rating.cylindrical._592": ["RatingMethod"],
        "_private.gears.rating.cylindrical._593": [
            "ReducedCylindricalGearSetDutyCycleRating"
        ],
        "_private.gears.rating.cylindrical._594": [
            "ScuffingFlashTemperatureRatingMethod"
        ],
        "_private.gears.rating.cylindrical._595": [
            "ScuffingIntegralTemperatureRatingMethod"
        ],
        "_private.gears.rating.cylindrical._596": ["ScuffingMethods"],
        "_private.gears.rating.cylindrical._597": ["ScuffingResultsRow"],
        "_private.gears.rating.cylindrical._598": ["ScuffingResultsRowGear"],
        "_private.gears.rating.cylindrical._599": ["TipReliefScuffingOptions"],
        "_private.gears.rating.cylindrical._600": ["ToothThicknesses"],
        "_private.gears.rating.cylindrical._601": [
            "VDI2737SafetyFactorReportingObject"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AGMAScuffingResultsRow",
    "CylindricalGearDesignAndRatingSettings",
    "CylindricalGearDesignAndRatingSettingsDatabase",
    "CylindricalGearDesignAndRatingSettingsItem",
    "CylindricalGearDutyCycleRating",
    "CylindricalGearFlankDutyCycleRating",
    "CylindricalGearFlankRating",
    "CylindricalGearMeshRating",
    "CylindricalGearMicroPittingResults",
    "CylindricalGearRating",
    "CylindricalGearRatingGeometryDataSource",
    "CylindricalGearScuffingResults",
    "CylindricalGearSetDutyCycleRating",
    "CylindricalGearSetRating",
    "CylindricalGearSingleFlankRating",
    "CylindricalMeshDutyCycleRating",
    "CylindricalMeshSingleFlankRating",
    "CylindricalPlasticGearRatingSettings",
    "CylindricalPlasticGearRatingSettingsDatabase",
    "CylindricalPlasticGearRatingSettingsItem",
    "CylindricalRateableMesh",
    "DynamicFactorMethods",
    "GearBlankFactorCalculationOptions",
    "ISOScuffingResultsRow",
    "MeshRatingForReports",
    "MicropittingRatingMethod",
    "MicroPittingResultsRow",
    "MisalignmentContactPatternEnhancements",
    "RatingMethod",
    "ReducedCylindricalGearSetDutyCycleRating",
    "ScuffingFlashTemperatureRatingMethod",
    "ScuffingIntegralTemperatureRatingMethod",
    "ScuffingMethods",
    "ScuffingResultsRow",
    "ScuffingResultsRowGear",
    "TipReliefScuffingOptions",
    "ToothThicknesses",
    "VDI2737SafetyFactorReportingObject",
)



"""RackSimulationCalculator"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import utility
from mastapy._private.gears.manufacturing.cylindrical.cutter_simulation import _857

_RACK_SIMULATION_CALCULATOR = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.CutterSimulation",
    "RackSimulationCalculator",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.manufacturing.cylindrical.cutter_simulation import (
        _866,
        _874,
    )

    Self = TypeVar("Self", bound="RackSimulationCalculator")
    CastSelf = TypeVar(
        "CastSelf", bound="RackSimulationCalculator._Cast_RackSimulationCalculator"
    )


__docformat__ = "restructuredtext en"
__all__ = ("RackSimulationCalculator",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_RackSimulationCalculator:
    """Special nested class for casting RackSimulationCalculator to subclasses."""

    __parent__: "RackSimulationCalculator"

    @property
    def cutter_simulation_calc(self: "CastSelf") -> "_857.CutterSimulationCalc":
        return self.__parent__._cast(_857.CutterSimulationCalc)

    @property
    def hob_simulation_calculator(self: "CastSelf") -> "_866.HobSimulationCalculator":
        from mastapy._private.gears.manufacturing.cylindrical.cutter_simulation import (
            _866,
        )

        return self.__parent__._cast(_866.HobSimulationCalculator)

    @property
    def worm_grinder_simulation_calculator(
        self: "CastSelf",
    ) -> "_874.WormGrinderSimulationCalculator":
        from mastapy._private.gears.manufacturing.cylindrical.cutter_simulation import (
            _874,
        )

        return self.__parent__._cast(_874.WormGrinderSimulationCalculator)

    @property
    def rack_simulation_calculator(self: "CastSelf") -> "RackSimulationCalculator":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class RackSimulationCalculator(_857.CutterSimulationCalc):
    """RackSimulationCalculator

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _RACK_SIMULATION_CALCULATOR

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def hob_working_depth_delta(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "HobWorkingDepthDelta")

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_RackSimulationCalculator":
        """Cast to another type.

        Returns:
            _Cast_RackSimulationCalculator
        """
        return _Cast_RackSimulationCalculator(self)
